from datetime import datetime
from typing import Optional

import attr


@attr.dataclass
class BukuLongitudinal:
    id_buku: str
    semester_id: str
    jumlah: int
    status_kelaikan: str
    id_buku_str: str
    semester_id_str: str
    buku_longitudinal_id: str
    create_date: Optional[datetime] = None
    last_update: Optional[datetime] = None
    soft_delete: Optional[str] = None
    last_sync: Optional[datetime] = None
    updater_id: Optional[str] = None



from dapodik.base import BaseDapodik
from typing import List, Type, TypeVar

from . import Validasi
from . import ValidasiSekolah
from . import ValidasiPrasarana
from . import ValidasiPesertaDidik
from . import ValidasiPtk
from . import ValidasiRombonganBelajar
from . import ValidasiPembelajaran
from . import ValidasiNilai
from . import ValidasiReferensi

V = TypeVar("V", bound=Validasi)


class BaseValidasi(BaseDapodik):
    def validasi_sekolah(
        self, page: int = 1, start: int = 0, limit: int = 50
    ) -> List[ValidasiSekolah]:
        """Data validasi Sekolah
        Args:
            page (int, optional): Halaman. Defaults to 1.
            start (int, optional): Dimulai dari. Defaults to 0.
            limit (int, optional): Batas data yang dikembalikan. Defaults to 50.
        Returns:
            List[Validasi]: list dari validasi
        """
        return self._validasi("sekolah", List[ValidasiSekolah], page, start, limit)

    def validasi_prasarana(
        self, page: int = 1, start: int = 0, limit: int = 50
    ) -> List[ValidasiPrasarana]:
        """Data validasi Sarpras
        Args:
            page (int, optional): Halaman. Defaults to 1.
            start (int, optional): Dimulai dari. Defaults to 0.
            limit (int, optional): Batas data yang dikembalikan. Defaults to 50.
        Returns:
            List[Validasi]: list dari validasi
        """
        return self._validasi("prasarana", List[ValidasiPrasarana], page, start, limit)

    def validasi_peserta_didik(
        self, page: int = 1, start: int = 0, limit: int = 50
    ) -> List[ValidasiPesertaDidik]:
        """Data validasi Peserta Didik
        Args:
            page (int, optional): Halaman. Defaults to 1.
            start (int, optional): Dimulai dari. Defaults to 0.
            limit (int, optional): Batas data yang dikembalikan. Defaults to 50.
        Returns:
            List[Validasi]: list dari validasi
        """
        return self._validasi(
            "peserta_didik", List[ValidasiPesertaDidik], page, start, limit
        )

    def validasi_ptk(
        self, page: int = 1, start: int = 0, limit: int = 50
    ) -> List[ValidasiPtk]:
        """Data validasi GTK
        Args:
            page (int, optional): Halaman. Defaults to 1.
            start (int, optional): Dimulai dari. Defaults to 0.
            limit (int, optional): Batas data yang dikembalikan. Defaults to 50.
        Returns:
            List[Validasi]: list dari validasi
        """
        return self._validasi("ptk", List[ValidasiPtk], page, start, limit)

    def validasi_rombongan_belajar(
        self, page: int = 1, start: int = 0, limit: int = 50
    ) -> List[ValidasiRombonganBelajar]:
        """Data validasi Rombongan Belajar & Jadwal
        Args:
            page (int, optional): Halaman. Defaults to 1.
            start (int, optional): Dimulai dari. Defaults to 0.
            limit (int, optional): Batas data yang dikembalikan. Defaults to 50.
        Returns:
            List[Validasi]: list dari validasi
        """
        return self._validasi(
            "rombongan_belajar", List[ValidasiRombonganBelajar], page, start, limit
        )

    def validasi_pembelajaran(
        self, page: int = 1, start: int = 0, limit: int = 50
    ) -> List[ValidasiPembelajaran]:
        """Data validasi Pembelajaran
        Args:
            page (int, optional): Halaman. Defaults to 1.
            start (int, optional): Dimulai dari. Defaults to 0.
            limit (int, optional): Batas data yang dikembalikan. Defaults to 50.
        Returns:
            List[Validasi]: list dari validasi
        """
        return self._validasi(
            "pembelajaran", List[ValidasiPembelajaran], page, start, limit
        )

    def validasi_nilai(
        self, page: int = 1, start: int = 0, limit: int = 50
    ) -> List[ValidasiNilai]:
        """Data validasi Nilai
        Args:
            page (int, optional): Halaman. Defaults to 1.
            start (int, optional): Dimulai dari. Defaults to 0.
            limit (int, optional): Batas data yang dikembalikan. Defaults to 50.
        Returns:
            List[Validasi]: list dari validasi
        """
        return self._validasi("nilai", List[ValidasiNilai], page, start, limit)

    def validasi_referensi(
        self, page: int = 1, start: int = 0, limit: int = 50
    ) -> List[ValidasiReferensi]:
        """Data validasi Referensi
        Args:
            page (int, optional): Halaman. Defaults to 1.
            start (int, optional): Dimulai dari. Defaults to 0.
            limit (int, optional): Batas data yang dikembalikan. Defaults to 50.
        Returns:
            List[Validasi]: list dari validasi
        """
        return self._validasi("referensi", List[ValidasiReferensi], page, start, limit)

    def _validasi(
        self,
        jenis_validasi: str,
        tipe_validasi: Type[List[V]],
        page: int = 1,
        start: int = 0,
        limit: int = 50,
    ) -> List[V]:
        params = {
            "jenis_validasi": jenis_validasi,
            "page": page,
            "start": start,
            "limit": limit,
        }
        return self._get_rows(path="validation", query=params, cl=tipe_validasi)



import attr
from datetime import datetime
from typing import Optional

from dapodik.base import BaseProp


@attr.dataclass(frozen=True, slots=True)
class AlatTransportasi:
    alat_transportasi_id: int
    nama: str
    create_date: datetime
    last_update: datetime
    expired_date: Optional[datetime]
    last_sync: datetime

    def __str__(self):
        return self.nama

    class Prop(BaseProp):
        @property
        def alat_transportasi(self) -> "AlatTransportasi":
            return self.dapodik._find(
                self.dapodik.alat_transportasi(),
                lambda x: x.alat_transportasi_id
                == getattr(self, "alat_transportasi_id"),
            )

        @alat_transportasi.setter
        def alat_transportasi(self, value: "AlatTransportasi"):
            new_alat_transportasi = self.dapodik._find(
                self.dapodik.alat_transportasi(),
                lambda x: x.alat_transportasi_id == value.alat_transportasi_id,
            )
            setattr(
                self, "alat_transportasi_id", new_alat_transportasi.alat_transportasi_id
            )



import attr
from datetime import datetime
from typing import Optional

from dapodik.base import BaseProp


@attr.dataclass(frozen=True, slots=True)
class KebutuhanKhusus:
    kebutuhan_khusus_id: int
    kebutuhan_khusus: str
    kk_a: str
    kk_b: str
    kk_c: str
    kk_c1: str
    kk_d: str
    kk_d1: str
    kk_e: str
    kk_f: str
    kk_h: str
    kk_i: str
    kk_j: str
    kk_k: str
    kk_n: str
    kk_o: str
    kk_p: str
    kk_q: str
    untuk_lembaga: str
    untuk_ptk: str
    untuk_pd: str
    create_date: datetime
    last_update: datetime
    expired_date: Optional[datetime]
    last_sync: datetime

    def __str__(self):
        return self.kebutuhan_khusus

    class Prop(BaseProp):
        @property
        def kebutuhan_khusus(self) -> "KebutuhanKhusus":
            return self.dapodik._find(
                self.dapodik.kebutuhan_khusus(),
                lambda x: x.kebutuhan_khusus_id == getattr(self, "kebutuhan_khusus_id"),
            )

        @kebutuhan_khusus.setter
        def kebutuhan_khusus(self, value: "KebutuhanKhusus"):
            new = self.dapodik._find(
                self.dapodik.kebutuhan_khusus(),
                lambda x: x.kebutuhan_khusus_id == value.kebutuhan_khusus_id,
            )
            setattr(self, "kebutuhan_khusus_id", new.kebutuhan_khusus_id)



from datetime import datetime

import attr


@attr.dataclass
class SekolahPaud:
    sekolah_id: str
    kategori_tk_id: int
    klasifikasi_lembaga_id: int
    sumber_dana_sekolah_id: str
    fasilitas_layanan_id: int
    jadwal_pmtas: str
    lembaga_pengangkat_id: int
    jadwal_ddtk: str
    freq_parenting: str
    bentuk_lembaga_id: str
    jadwal_kesehatan: str
    izin_paud: str
    pencatatan_ddtk: str
    rujukan_ddtk: str
    pelaksanaan_parenting: str
    parenting_kpo: str
    parenting_kelas: str
    parenting_kegiatan: str
    parenting_konsultasi: str
    parenting_kunjungan: str
    parenting_lainnya: str
    nilk: str
    nilm: str
    no_penetapan_pnf: str
    tanggal_penetapan_pnf: str
    create_date: datetime
    last_update: datetime
    soft_delete: str
    last_sync: datetime
    updater_id: str



#!/usr/bin/env python
import sys
from . import __version__, __dapodik_version__, __semester__, __tahun_ajaran__


def print_ver():
    print("python dapodik versi v{}".format(__version__))
    print("Client / SDK python untuk dapodik versi {}".format(__dapodik_version__))
    print("Semester {}".format(__semester__))
    print("Tahun ajaran {}".format(__tahun_ajaran__))
    print("Python {}".format(sys.version.replace("\n", " ")))


def main():
    sys.exit(print_ver())


if __name__ == "__main__":
    main()



from datetime import datetime
from typing import Optional

import attr


@attr.dataclass
class AlatDariBlockgrant:
    blockgrant_id: str
    id_alat: str
    blockgrant_id_str: str = ""
    id_alat_str: str = ""
    alat_dari_blockgrant_id: str = "Admin.model.AlatDariBlockgrant-1"
    create_date: Optional[datetime] = None
    last_update: Optional[datetime] = None
    soft_delete: Optional[str] = None
    last_sync: Optional[datetime] = None
    updater_id: Optional[str] = None



from datetime import datetime
from typing import Optional

import attr


@attr.dataclass
class Angkutan:
    id_angkutan: str
    sekolah_id: str
    ptk_id: Optional[str]
    jenis_sarana_id: int
    id_hapus_buku: Optional[str]
    kepemilikan_sarpras_id: str
    kd_kl: Optional[str]
    kd_satker: Optional[str]
    kd_brg: Optional[str]
    nup: Optional[int]
    kode_eselon1: Optional[str]
    nama_eselon1: Optional[str]
    kode_sub_satker: Optional[str]
    nama_sub_satker: Optional[str]
    nama: str
    spesifikasi: Optional[str]
    tgl_hapus_buku: Optional[str]
    merk: Optional[str]
    no_polisi: Optional[str]
    no_bpkb: Optional[str]
    alamat: Optional[str]
    asal_data: Optional[str]
    jenis_sarana_id_str: str
    sekolah_id_str: str
    vld_count: int
    create_date: Optional[datetime] = None
    last_update: Optional[datetime] = None
    soft_delete: Optional[str] = None
    last_sync: Optional[datetime] = None
    updater_id: Optional[str] = None

    def __str__(self):
        return self.nama



import attr
from datetime import datetime
from typing import Optional

from dapodik.base import BaseProp


@attr.dataclass(frozen=True, slots=True)
class JenisLk:
    id_jenis_lk: str
    nm_jenis_lk: str
    ket_jenis_lk: Optional[str]
    create_date: datetime
    last_update: datetime
    expired_date: Optional[datetime]
    last_sync: datetime

    def __str__(self):
        return self.nm_jenis_lk

    class Prop(BaseProp):
        @property
        def jenis_lk(self) -> "JenisLk":
            return self.dapodik._find(
                self.dapodik.jenis_lk(),
                lambda x: x.id_jenis_lk == getattr(self, "id_jenis_lk"),
            )

        @jenis_lk.setter
        def jenis_lk(self, value: "JenisLk"):
            new_jenis_lk = self.dapodik._find(
                self.dapodik.jenis_lk(),
                lambda x: x.id_jenis_lk == value.id_jenis_lk,
            )
            setattr(self, "id_jenis_lk", new_jenis_lk.id_jenis_lk)



from datetime import datetime
from typing import Optional

import attr


@attr.dataclass
class BangunanDariBlockgrant:
    blockgrant_id: str
    id_bangunan: str
    blockgrant_id_str: str
    id_bangunan_str: str
    bangunan_dari_blockgrant_id: str
    create_date: Optional[datetime] = None
    last_update: Optional[datetime] = None
    soft_delete: Optional[str] = None
    last_sync: Optional[datetime] = None
    updater_id: Optional[str] = None



from datetime import datetime
from uuid import UUID

import attr

DEF = "Admin.model.PesertaDidikLongitudinal-1"


@attr.dataclass
class PesertaDidikLongitudinal:
    peserta_didik_id: UUID
    semester_id: str
    tinggi_badan: int
    berat_badan: int
    lingkar_kepala: int
    jarak_rumah_ke_sekolah: int
    jarak_rumah_ke_sekolah_km: int
    waktu_tempuh_ke_sekolah: int
    menit_tempuh_ke_sekolah: int
    jumlah_saudara_kandung: int
    create_date: datetime
    last_update: datetime
    soft_delete: int
    last_sync: datetime
    updater_id: UUID
    peserta_didik_longitudinal_id_str: str
    peserta_didik_id_str: str
    semester_id_str: int
    peserta_didik_longitudinal_id: str
    vld_count: int

    @property
    def waktu_tempuh(self) -> int:
        return self.waktu_tempuh_ke_sekolah * 60 + self.menit_tempuh_ke_sekolah

    def __str__(self):
        return (
            f"TB: {self.tinggi_badan}; BB: {self.berat_badan}; LK: {self.lingkar_kepala}; "
            f""
        )

    @attr.dataclass
    class Create:
        peserta_didik_longitudinal_id: str
        semester_id: str
        peserta_didik_id: UUID
        tinggi_badan: int
        berat_badan: int
        jarak_rumah_ke_sekolah_km: int
        jarak_rumah_ke_sekolah: int
        waktu_tempuh_ke_sekolah: int
        menit_tempuh_ke_sekolah: int
        jumlah_saudara_kandung: int
        lingkar_kepala: int
        vld_count: int = 0
        peserta_didik_longitudinal_id_str: str = ""
        peserta_didik_id_str: str = ""
        semester_id_str: str = ""



from bs4 import BeautifulSoup
from typing import List

from dapodik.base import BaseDapodik
from dapodik.exception import PasswordSalah, PenggunaTidakTerdaftar, ServerTidakMerespon
from . import Pengguna


class BaseAuth(BaseDapodik):
    def login(
        self,
        username: str,
        password: str,
        rememberme: bool = True,
        semester_id: str = "20202",
        pengguna: int = None,
    ) -> List[Pengguna]:
        """Login ke dapodik dan mendapatkan daftar Pengguna

        Args:
            username (str): Email dapodik
            password (str): Password dapodik
            semester_id (str, optional): Id semester. Defaults to "20202".

        Raises:
            ServerTidakMerespon: Server dapodik tidak merespon
            PenggunaTidakTerdaftar: Username yang Anda masukkan tidak terdaftar!
            PasswordSalah: Password yang Anda masukkan salah!

        Returns:
            List[Pengguna]: list dari Pengguna
        """
        res = self._get("")
        if not res.ok:
            raise ServerTidakMerespon(f"Server dapodik ({self.base_url}) tidak merespon")
        data = {"username": username, "password": password, "semester_id": semester_id}
        if rememberme:
            data["rememberme"] = "on"
        res = self._post("roleperan", data)
        redirect = res.request.url or res.url
        # Check error
        if redirect.endswith("#PenggunaTidakTerdaftar"):
            raise PenggunaTidakTerdaftar(
                "Username yang Anda masukkan tidak terdaftar! Mohon gunakan username lain."
            )
        elif redirect.endswith("#PasswordSalah"):
            raise PasswordSalah("Password yang Anda masukkan salah!")
        soup = BeautifulSoup(res.text, "html.parser")
        daftar_pengguna = Pengguna.from_soup(soup, self.base_url)
        if pengguna is None:
            return daftar_pengguna
        self.login_pengguna(daftar_pengguna[pengguna])
        return daftar_pengguna

    def login_pengguna(self, pengguna: Pengguna) -> bool:
        """Login dengan Pengguna

        Args:
            pengguna (Pengguna): Pengguna dari .login()

        Returns:
            bool: Berhasil / tidaknya login
        """
        res = self._get(pengguna.login_url)
        return res.ok

    def logout(self) -> bool:
        """Logout dari dapodik

        Returns:
            bool: logout berhasil / tidak
        """
        return self._get("destauth").ok



from datetime import datetime, date
from typing import Optional

import attr


@attr.dataclass(frozen=True, slots=True)
class TahunAjaran:
    tahun_ajaran_id: str
    nama: str
    periode_aktif: str
    tanggal_mulai: date
    tanggal_selesai: date
    create_date: datetime
    last_update: datetime
    expired_date: Optional[datetime]
    last_sync: datetime

    def __str__(self):
        return self.nama



import attr
from datetime import datetime
from typing import Optional

from dapodik.base import BaseProp


@attr.dataclass(frozen=True, slots=True)
class Biblio:
    id_biblio: str
    id_freq: Optional[str]
    id_publisher: str
    negara_id: str
    id_gmd: str
    id_classification: Optional[str]
    create_date: str
    title: str
    sor: Optional[str]
    edition: Optional[str]
    isbn_issn: Optional[str]
    collations: str
    publisher: Optional[str]
    publish_year: Optional[str]
    series_title: Optional[str]
    call_number: Optional[str]
    source: Optional[str]
    publish_place: Optional[str]
    notes: Optional[str]
    image: Optional[str]
    file_att: Optional[str]
    opac_hide: Optional[str]
    promoted: Optional[str]
    labels: Optional[str]
    paper_printing_spec: Optional[str]
    last_sync: datetime
    last_update: datetime
    expired_date: Optional[datetime]
    id_publisher_str: str
    id_gmd_str: str
    tingkat_pendidikan_id: str
    tingkat_pendidikan_id_str: str

    def __str__(self):
        return self.title

    class Prop(BaseProp):
        @property
        def biblio(self) -> "Biblio":
            return self.dapodik._find(
                self.dapodik.biblio(),
                lambda x: x.id_biblio == getattr(self, "id_biblio"),
            )

        @biblio.setter
        def biblio(self, value: "Biblio"):
            new_id_biblio = self.dapodik._find(
                self.dapodik.biblio(),
                lambda x: x.id_biblio == value.id_biblio,
            )
            setattr(self, "id_biblio", new_id_biblio.id_biblio)



from datetime import datetime
from typing import Optional

import attr


@attr.dataclass
class ProgramInklusi:
    id_pi: str
    sekolah_id: str
    kebutuhan_khusus_id: int
    sk_pi: str
    tgl_sk_pi: str
    tmt_pi: str
    tst_pi: Optional[str]
    ket_pi: str
    asal_data: str
    create_date: datetime
    last_update: datetime
    soft_delete: str
    last_sync: datetime
    updater_id: str
    sekolah_id_str: str
    kebutuhan_khusus_id_str: str



from typing import List

from dapodik.base import BaseDapodik

from . import Agama
from . import Akreditasi
from . import AksesInternet
from . import AlatTransportasi
from . import Bank
from . import BentukLembaga
from . import Biblio
from . import FasilitasLayanan
from . import Gmd
from . import JadwalPaud
from . import JenisCita
from . import JenisGugus
from . import JenisHapusBuku
from . import JenisHobby
from . import JenisKeluar
from . import JenisLk
from . import JenisPendaftaran
from . import JenisPrasarana
from . import JenisPtk
from . import JenisRombel
from . import JenisSarana
from . import JenisTinggal
from . import JenjangPendidikan
from . import Jurusan
from . import KategoriTk
from . import KeahlianLaboratorium
from . import KebutuhanKhusus
from . import KlasifikasiLembaga
from . import Kurikulum
from . import LembagaPengangkat
from . import MataPelajaran
from . import MstWilayah
from . import PangkatGolongan
from . import Pekerjaan
from . import Penghasilan
from . import RolePengguna
from . import StatusKeaktifanPegawai
from . import StatusKepegawaian
from . import StatusKepemilikanSarpras
from . import SumberAir
from . import SumberDanaSekolah
from . import SumberGaji
from . import SumberListrik
from . import SyncLog
from . import TahunAjaran
from . import TingkatPendidikan
from . import WaktuPenyelenggaraan


class BaseRest(BaseDapodik):
    def agama(
        self, agama_id: int = None, page: int = 1, start: int = 0, limit: int = 50
    ) -> List[Agama]:
        return self._get_rest(
            "Agama",
            List[Agama],
            page,
            start,
            limit,
            query=self._query(agama_id=agama_id),
        )

    def akreditasi(
        self, akreditasi_id: int = None, page: int = 1, start: int = 0, limit: int = 50
    ) -> List[Akreditasi]:
        return self._get_rest(
            "Akreditasi",
            List[Akreditasi],
            page,
            start,
            limit,
            query=self._query(akreditasi_id=akreditasi_id),
        )

    def akses_internet(
        self,
        akses_internet_id: int = None,
        page: int = 1,
        start: int = 0,
        limit: int = 50,
    ) -> List[AksesInternet]:
        return self._get_rest(
            "AksesInternet",
            List[AksesInternet],
            page,
            start,
            limit,
            query=self._query(akses_internet_id=akses_internet_id),
        )

    def alat_transportasi(
        self,
        alat_transportasi_id: int = None,
        page: int = 1,
        start: int = 0,
        limit: int = 50,
    ) -> List[AlatTransportasi]:
        return self._get_rest(
            "AlatTransportasi",
            List[AlatTransportasi],
            page,
            start,
            limit,
            self._query(alat_transportasi_id=alat_transportasi_id),
        )

    def bank(
        self, id_bank: str = None, page: int = 1, start: int = 0, limit: int = 50
    ) -> List[Bank]:
        return self._get_rest(
            "Bank", List[Bank], page, start, limit, query=self._query(id_bank=id_bank)
        )

    def bentuk_lembaga(
        self,
        bentuk_lembaga_id: int = None,
        page: int = 1,
        start: int = 0,
        limit: int = 50,
    ) -> List[BentukLembaga]:
        return self._get_rest(
            "BentukLembaga",
            List[BentukLembaga],
            page,
            start,
            limit,
            query=self._query(bentuk_lembaga_id=bentuk_lembaga_id),
        )

    def biblio(
        self, id_biblio: str = None, page: int = 1, start: int = 0, limit: int = 50
    ) -> List[Biblio]:
        return self._get_rest(
            "Biblio",
            List[Biblio],
            page,
            start,
            limit,
            query=self._query(id_biblio=id_biblio),
        )

    def fasilitas_layanan(
        self,
        fasilitas_layanan_id: int = None,
        page: int = 1,
        start: int = 0,
        limit: int = 50,
    ) -> List[FasilitasLayanan]:
        return self._get_rest(
            "FasilitasLayanan",
            List[FasilitasLayanan],
            page,
            start,
            limit,
            query=self._query(fasilitas_layanan_id=fasilitas_layanan_id),
        )

    def gmd(
        self, id_gmd: str = None, page: int = 1, start: int = 0, limit: int = 50
    ) -> List[Gmd]:
        return self._get_rest(
            "Gmd", List[Gmd], page, start, limit, query=self._query(id_gmd=id_gmd)
        )

    def jadwal_paud(
        self, jadwal_id: int = None, page: int = 1, start: int = 0, limit: int = 50
    ) -> List[JadwalPaud]:
        return self._get_rest(
            "JadwalPaud",
            List[JadwalPaud],
            page,
            start,
            limit,
            query=self._query(jadwal_id=jadwal_id),
        )

    def jenis_cita(
        self, id_cita: int = None, page: int = 1, start: int = 0, limit: int = 50
    ) -> List[JenisCita]:
        return self._get_rest(
            "JenisCita",
            List[JenisCita],
            page,
            start,
            limit,
            query=self._query(id_cita=id_cita),
        )

    def jenis_gugus(
        self, jenis_gugus_id: int = None, page: int = 1, start: int = 0, limit: int = 50
    ) -> List[JenisGugus]:
        return self._get_rest(
            "JenisGugus",
            List[JenisGugus],
            page,
            start,
            limit,
            query=self._query(jenis_gugus_id=jenis_gugus_id),
        )

    def jenis_hapus_buku(
        self, id_hapus_buku: int = None, page: int = 1, start: int = 0, limit: int = 50
    ) -> List[JenisHapusBuku]:
        return self._get_rest(
            "JenisHapusBuku",
            List[JenisHapusBuku],
            page,
            start,
            limit,
            query=self._query(id_hapus_buku=id_hapus_buku),
        )

    def jenis_hobby(
        self, id_hobby: int = None, page: int = 1, start: int = 0, limit: int = 50
    ) -> List[JenisHobby]:
        return self._get_rest(
            "JenisHobby",
            List[JenisHobby],
            page,
            start,
            limit,
            query=self._query(id_hobby=id_hobby),
        )

    def jenis_keluar(
        self,
        jenis_keluar_id: int = None,
        page: int = 1,
        start: int = 0,
        limit: int = 50,
    ) -> List[JenisKeluar]:
        return self._get_rest(
            "JenisKeluar",
            List[JenisKeluar],
            page,
            start,
            limit,
            query=self._query(jenis_keluar_id=jenis_keluar_id),
        )

    def jenis_lk(
        self, id_jenis_lk: str = None, page: int = 1, start: int = 0, limit: int = 50
    ) -> List[JenisLk]:
        return self._get_rest(
            "JenisLk", List[JenisLk], page, start, limit, query=self._query(id_jenis_lk)
        )

    def jenis_pendaftaran(
        self,
        jenis_pendaftaran_id: int = None,
        page: int = 1,
        start: int = 0,
        limit: int = 50,
    ) -> List[JenisPendaftaran]:
        return self._get_rest(
            "JenisPendaftaran",
            List[JenisPendaftaran],
            page,
            start,
            limit,
            query=self._query(jenis_pendaftaran_id=jenis_pendaftaran_id),
        )

    def jenis_prasarana(
        self,
        jenis_prasarana_id: int = None,
        page: int = 1,
        start: int = 0,
        limit: int = 50,
    ) -> List[JenisPrasarana]:
        return self._get_rest(
            "JenisPrasarana",
            List[JenisPrasarana],
            page,
            start,
            limit,
            query=self._query(jenis_prasarana_id=jenis_prasarana_id),
        )

    def jenis_ptk(
        self, jenis_ptk_id: int = None, page: int = 1, start: int = 0, limit: int = 50
    ) -> List[JenisPtk]:
        return self._get_rest(
            "JenisPtk",
            List[JenisPtk],
            page,
            start,
            limit,
            query=self._query(jenis_ptk_id=jenis_ptk_id),
        )

    def jenis_rombel(
        self, jenis_rombel: int = None, page: int = 1, start: int = 0, limit: int = 50
    ) -> List[JenisRombel]:
        return self._get_rest(
            "JenisRombel",
            List[JenisRombel],
            page,
            start,
            limit,
            query=self._query(jenis_rombel=jenis_rombel),
        )

    def jenis_sarana(
        self,
        jenis_sarana_id: int = None,
        page: int = 1,
        start: int = 0,
        limit: int = 50,
    ) -> List[JenisSarana]:
        return self._get_rest(
            "JenisSarana",
            List[JenisSarana],
            page,
            start,
            limit,
            query=self._query(jenis_sarana_id=jenis_sarana_id),
        )

    def jenis_tinggal(
        self,
        jenis_tinggal_id: int = None,
        page: int = 1,
        start: int = 0,
        limit: int = 50,
    ) -> List[JenisTinggal]:
        return self._get_rest(
            "JenisTinggal",
            List[JenisTinggal],
            page,
            start,
            limit,
            query=self._query(jenis_tinggal_id=jenis_tinggal_id),
        )

    def jenjang_pendidikan(
        self,
        jenjang_pendidikan_id: int = None,
        page: int = 1,
        start: int = 0,
        limit: int = 50,
    ) -> List[JenjangPendidikan]:
        return self._get_rest(
            "JenjangPendidikan",
            List[JenjangPendidikan],
            page,
            start,
            limit,
            query=self._query(jenjang_pendidikan_id=jenjang_pendidikan_id),
        )

    def jurusan(
        self, jurusan_id: int = None, page: int = 1, start: int = 0, limit: int = 50
    ) -> List[Jurusan]:
        return self._get_rest(
            "Jurusan",
            List[Jurusan],
            page,
            start,
            limit,
            query=self._query(jurusan_id=jurusan_id),
        )

    def kategori_tk(
        self, kategori_tk_id: int = None, page: int = 1, start: int = 0, limit: int = 50
    ) -> List[KategoriTk]:
        return self._get_rest(
            "KategoriTk",
            List[KategoriTk],
            page,
            start,
            limit,
            query=self._query(kategori_tk_id=kategori_tk_id),
        )

    def keahlian_laboratorium(
        self,
        keahlian_laboratorium_id: int = None,
        page: int = 1,
        start: int = 0,
        limit: int = 50,
    ) -> List[KeahlianLaboratorium]:
        return self._get_rest(
            "KeahlianLaboratorium",
            List[KeahlianLaboratorium],
            page,
            start,
            limit,
            query=self._query(keahlian_laboratorium_id=keahlian_laboratorium_id),
        )

    def kebutuhan_khusus(
        self,
        kebutuhan_khusus_id: int = None,
        page: int = 1,
        start: int = 0,
        limit: int = 50,
    ) -> List[KebutuhanKhusus]:
        return self._get_rest(
            "KebutuhanKhusus",
            List[KebutuhanKhusus],
            page,
            start,
            limit,
            query=self._query(kebutuhan_khusus_id=kebutuhan_khusus_id),
        )

    def klasifikasi_lembaga(
        self,
        klasifikasi_lembaga_id: int = None,
        page: int = 1,
        start: int = 0,
        limit: int = 50,
    ) -> List[KlasifikasiLembaga]:
        return self._get_rest(
            "KlasifikasiLembaga",
            List[KlasifikasiLembaga],
            page,
            start,
            limit,
            query=self._query(klasifikasi_lembaga_id=klasifikasi_lembaga_id),
        )

    def kurikulum(
        self, kurikulum_id: int = None, page: int = 1, start: int = 0, limit: int = 50
    ) -> List[Kurikulum]:
        return self._get_rest(
            "Kurikulum",
            List[Kurikulum],
            page,
            start,
            limit,
            query=self._query(kurikulum_id=kurikulum_id),
        )

    def lembaga_pengangkat(
        self,
        lembaga_pengangkat_id: int = None,
        page: int = 1,
        start: int = 0,
        limit: int = 50,
    ) -> List[LembagaPengangkat]:
        return self._get_rest(
            "LembagaPengangkat",
            List[LembagaPengangkat],
            page,
            start,
            limit,
            query=self._query(lembaga_pengangkat_id=lembaga_pengangkat_id),
        )

    def mata_pelajaran(
        self,
        mata_pelajaran_id: int = None,
        page: int = 1,
        start: int = 0,
        limit: int = 50,
    ) -> List[MataPelajaran]:
        return self._get_rest(
            "MataPelajaran",
            List[MataPelajaran],
            page,
            start,
            limit,
            query=self._query(mata_pelajaran_id=mata_pelajaran_id),
        )

    def mst_wilayah(
        self, kode_wilayah: str = None, page: int = 1, start: int = 0, limit: int = 50
    ) -> List[MstWilayah]:
        return self._get_rest(
            "MstWilayah",
            List[MstWilayah],
            page,
            start,
            limit,
            query=self._query(kode_wilayah=kode_wilayah),
        )

    def pangkat_golongan(
        self,
        pangkat_golongan_id: int = None,
        page: int = 1,
        start: int = 0,
        limit: int = 50,
    ) -> List[PangkatGolongan]:
        return self._get_rest(
            "PangkatGolongan",
            List[PangkatGolongan],
            page,
            start,
            limit,
            query=self._query(pangkat_golongan_id=pangkat_golongan_id),
        )

    def pekerjaan(
        self, pekerjaan_id: int = None, page: int = 1, start: int = 0, limit: int = 50
    ) -> List[Pekerjaan]:
        return self._get_rest(
            "Pekerjaan",
            List[Pekerjaan],
            page,
            start,
            limit,
            query=self._query(pekerjaan_id=pekerjaan_id),
        )

    def penghasilan(
        self, penghasilan_id: int = None, page: int = 1, start: int = 0, limit: int = 50
    ) -> List[Penghasilan]:
        return self._get_rest(
            "Penghasilan",
            List[Penghasilan],
            page,
            start,
            limit,
            query=self._query(penghasilan_id=penghasilan_id),
        )

    def role_pengguna(
        self, page: int = 1, start: int = 0, limit: int = 50
    ) -> List[RolePengguna]:
        return self._get_rest("RolePengguna", List[RolePengguna], page, start, limit)

    def status_keaktifan_pegawai(
        self,
        status_keaktifan_id: int = None,
        page: int = 1,
        start: int = 0,
        limit: int = 50,
    ) -> List[StatusKeaktifanPegawai]:
        return self._get_rest(
            "StatusKeaktifanPegawai",
            List[StatusKeaktifanPegawai],
            page,
            start,
            limit,
            query=self._query(status_keaktifan_id=status_keaktifan_id),
        )

    def status_kepegawaian(
        self,
        status_kepegawaian_id: int = None,
        page: int = 1,
        start: int = 0,
        limit: int = 50,
    ) -> List[StatusKepegawaian]:
        return self._get_rest(
            "StatusKepegawaian",
            List[StatusKepegawaian],
            page,
            start,
            limit,
            query=self._query(status_kepegawaian_id=status_kepegawaian_id),
        )

    def status_kepemilikan_sarpras(
        self, page: int = 1, start: int = 0, limit: int = 50
    ) -> List[StatusKepemilikanSarpras]:
        return self._get_rest(
            "StatusKepemilikanSarpras",
            List[StatusKepemilikanSarpras],
            page,
            start,
            limit,
        )

    def sumber_air(
        self, page: int = 1, start: int = 0, limit: int = 50
    ) -> List[SumberAir]:
        return self._get_rest("SumberAir", List[SumberAir], page, start, limit)

    def sumber_dana_sekolah(
        self, page: int = 1, start: int = 0, limit: int = 50
    ) -> List[SumberDanaSekolah]:
        return self._get_rest(
            "SumberDanaSekolah", List[SumberDanaSekolah], page, start, limit
        )

    def sumber_gaji(
        self, page: int = 1, start: int = 0, limit: int = 50
    ) -> List[SumberGaji]:
        return self._get_rest("SumberGaji", List[SumberGaji], page, start, limit)

    def sumber_listrik(
        self, page: int = 1, start: int = 0, limit: int = 50
    ) -> List[SumberListrik]:
        return self._get_rest("SumberListrik", List[SumberListrik], page, start, limit)

    def sync_log(
        self, sync_log_id: str = None, page: int = 1, start: int = 0, limit: int = 50
    ) -> List[SyncLog]:
        return self._get_rest(
            "SyncLog",
            List[SyncLog],
            page,
            start,
            limit,
            query=self._query(sync_log_id=sync_log_id),
        )

    def tahun_ajaran(
        self,
        tahun_ajaran_id: str = None,
        page: int = 1,
        start: int = 0,
        limit: int = 50,
    ) -> List[TahunAjaran]:
        return self._get_rest(
            "TahunAjaran",
            List[TahunAjaran],
            page,
            start,
            limit,
            query=self._query(tahun_ajaran_id=tahun_ajaran_id),
        )

    def tingkat_pendidikan(
        self,
        tingkat_pendidikan_id: int = None,
        page: int = 1,
        start: int = 0,
        limit: int = 50,
    ) -> List[TingkatPendidikan]:
        return self._get_rest(
            "TingkatPendidikan",
            List[TingkatPendidikan],
            page,
            start,
            limit,
            query=self._query(tingkat_pendidikan_id=tingkat_pendidikan_id),
        )

    def waktu_penyelenggaraan(
        self,
        waktu_penyelenggaraan_id: int = None,
        page: int = 1,
        start: int = 0,
        limit: int = 50,
    ) -> List[WaktuPenyelenggaraan]:
        return self._get_rest(
            "WaktuPenyelenggaraan",
            List[WaktuPenyelenggaraan],
            page,
            start,
            limit,
            query=self._query(waktu_penyelenggaraan_id=waktu_penyelenggaraan_id),
        )



import attr
from datetime import datetime
from typing import Optional

from dapodik.base import BaseProp


@attr.dataclass(frozen=True, slots=True)
class JenisRombel:
    jenis_rombel: int
    nm_jenis_rombel: str
    create_date: datetime
    last_update: datetime
    expired_date: Optional[datetime]
    last_sync: datetime

    def __str__(self):
        return self.nm_jenis_rombel

    class Prop(BaseProp):
        @property
        def jenisrombel(self) -> "JenisRombel":
            return self.dapodik._find(
                self.dapodik.jenis_rombel(),
                lambda x: x.jenis_rombel == getattr(self, "jenis_rombel"),
            )

        @jenisrombel.setter
        def jenisrombel(self, value: "JenisRombel"):
            new = self.dapodik._find(
                self.dapodik.jenis_rombel(),
                lambda x: x.jenis_rombel == value.jenis_rombel,
            )
            setattr(self, "jenis_rombel", new.jenis_rombel)



from datetime import datetime
from typing import Optional

import attr


@attr.dataclass
class TanahLongitudinal:
    id_tanah: str
    njop: float
    tahun_ajaran_id: int
    tahun_ajaran_id_str: str = ""
    id_tanah_str: str = ""
    tanah_longitudinal_id: str = "Admin.model.TanahLongitudinal-2"
    tanah_longitudinal_id_str: str = ""
    create_date: Optional[datetime] = None
    last_update: Optional[datetime] = None
    soft_delete: Optional[str] = None
    last_sync: Optional[datetime] = None
    updater_id: Optional[str] = None



from datetime import datetime, date
from typing import Optional
from uuid import UUID

import attr


@attr.dataclass
class PesertaDidikBaru:
    pdb_id: UUID
    sekolah_id: UUID
    nama_pd: str
    jenis_kelamin: str
    nik: str
    tempat_lahir: str
    tanggal_lahir: date
    nama_ibu_kandung: str
    jenis_pendaftaran_id: int
    nisn: str
    sudah_diproses: int
    berhasil_diproses: int
    tahun_ajaran_id: int
    tahun_ajaran_id_str: str
    peserta_didik_id: UUID
    peserta_didik_id_str: UUID
    # Get only
    create_date: Optional[datetime] = None
    last_update: Optional[datetime] = None
    soft_delete: Optional[int] = None
    last_sync: Optional[datetime] = None
    updater_id: Optional[UUID] = None

    @attr.dataclass
    class Create:
        sekolah_id: UUID
        tahun_ajaran_id: int
        nama_pd: str
        jenis_kelamin: str
        nisn: str
        nik: str
        tempat_lahir: str
        tanggal_lahir: datetime
        nama_ibu_kandung: str
        jenis_pendaftaran_id: int
        sudah_diproses: int = 0
        berhasil_diproses: int = 0
        peserta_didik_id: str = ""
        pdb_id: str = "Admin.model.PesertaDidikBaru-1"
        sekolah_id_str: str = ""
        tahun_ajaran_id_str: str = ""
        jenis_pendaftaran_id_str: str = ""
        peserta_didik_id_str: str = ""



from datetime import datetime, date
from typing import Optional
from uuid import UUID

from dapodik import __semester__
import attr


@attr.dataclass
class RombonganBelajar:
    rombongan_belajar_id: UUID
    id_ruang: UUID
    sekolah_id: UUID
    tingkat_pendidikan_id: str
    jurusan_sp_id: Optional[str]
    kurikulum_id: int
    nama: str
    ptk_id: UUID
    moving_class: str
    jenis_rombel: int
    sks: str
    tanggal_mulai: date
    tanggal_selesai: date
    kebutuhan_khusus_id: int
    create_date: datetime
    last_update: datetime
    soft_delete: str
    last_sync: datetime
    updater_id: UUID
    semester_id_str: str
    sekolah_id_str: str
    kurikulum_id_str: str
    ptk_id_str: str
    id_ruang_str: str
    kebutuhan_khusus_id_str: str
    vld_count: int
    pembelajaran_count: int
    anggota_rombel_count: int
    jenis_rombel_str: str
    jurusan_id: int
    jurusan_id_str: str
    tingkat_pendidikan_id_str: str
    semester_id: str = __semester__



from datetime import datetime, date
from typing import Union


def str_to_datetime(
    data: Union[str, datetime], format: str = "%Y-%m-%d %H:%M:%S"
) -> datetime:
    if isinstance(data, datetime):
        return data
    elif type(data) == str:
        if "." in data:
            return datetime.strptime(data, format + ".%f")
        return datetime.strptime(data, format)
    else:
        return datetime.now()


def str_to_date(data: Union[str, date], format: str = "%Y-%m-%d") -> date:
    if isinstance(data, date):
        return data
    elif type(data) == str:
        return datetime.strptime(data, format).date()
    else:
        return datetime.now().date()



import attr
from datetime import datetime
from typing import Optional

from dapodik.base import BaseProp


@attr.dataclass(frozen=True, slots=True)
class AksesInternet:
    akses_internet_id: int
    nama: str
    media: str
    create_date: datetime
    last_update: datetime
    expired_date: Optional[datetime]
    last_sync: datetime

    def __str__(self):
        return self.nama

    class Prop(BaseProp):
        @property
        def akses_internet(self) -> "AksesInternet":
            return self.dapodik._find(
                self.dapodik.akses_internet(),
                lambda x: x.akses_internet_id == getattr(self, "akses_internet_id"),
            )

        @akses_internet.setter
        def akses_internet(self, value: "AksesInternet"):
            new_akses_internet = self.dapodik._find(
                self.dapodik.akses_internet(),
                lambda x: x.akses_internet_id == value.akses_internet_id,
            )
            setattr(self, "akses_internet_id", new_akses_internet.akses_internet_id)



from .akreditasi_sp import AkreditasiSp
from .blockgrant import BlockGrant
from .jurusan_sp import JurusanSp
from .kepanitiaan import Kepanitiaan
from .program_inklusi import ProgramInklusi
from .sanitasi import Sanitasi
from .sekolah_longitudinal import SekolahLongitudinal
from .sekolah_paud import SekolahPaud
from .sekolah import Sekolah
from .semester import Semester
from .yayasan import Yayasan

from .base import BaseSekolah


__all__ = [
    "AkreditasiSp",
    "BlockGrant",
    "JurusanSp",
    "Kepanitiaan",
    "ProgramInklusi",
    "Sanitasi",
    "SekolahLongitudinal",
    "SekolahPaud",
    "Sekolah",
    "Semester",
    "Yayasan",
    "BaseSekolah",
]



import attr
from datetime import datetime
from typing import Optional

from dapodik.base import BaseProp


@attr.dataclass(frozen=True, slots=True)
class JenisPendaftaran:
    jenis_pendaftaran_id: int
    nama: str
    daftar_sekolah: str
    daftar_rombel: str
    create_date: datetime
    last_update: datetime
    expired_date: Optional[datetime]
    last_sync: datetime

    def __str__(self):
        return self.nama

    class Prop(BaseProp):
        @property
        def jenis_pendaftaran(self) -> "JenisPendaftaran":
            return self.dapodik._find(
                self.dapodik.jenis_pendaftaran(),
                lambda x: x.jenis_pendaftaran_id
                == getattr(self, "jenis_pendaftaran_id"),
            )

        @jenis_pendaftaran.setter
        def jenis_pendaftaran(self, value: "JenisPendaftaran"):
            new = self.dapodik._find(
                self.dapodik.jenis_pendaftaran(),
                lambda x: x.jenis_pendaftaran_id == value.jenis_pendaftaran_id,
            )
            setattr(self, "jenis_pendaftaran_id", new.jenis_pendaftaran_id)



from bs4 import Tag
from typing import List

import attr


@attr.dataclass
class Pengguna:
    nama: str
    peran: str
    sekolah: str
    login_url: str
    photo: str

    @classmethod
    def from_li(cls, li: Tag, server: str = "") -> "Pengguna":
        a: Tag = li.find("a")
        spans: List[Tag] = li.findAll("span")
        login_url = str(server + a.attrs.get("href", "")[1:])
        # ERROR : bs4 parsing fault
        login_url = login_url.replace("¶ms", "&params")
        data = {
            "nama": spans[1].getText().split(":")[-1],
            "peran": spans[2].getText().split(":")[-1],
            "sekolah": spans[0].getText(),
            "login_url": login_url,
            "photo": server + a.find("img").attrs.get("src", ""),
        }
        return cls(**data)  # type: ignore

    @classmethod
    def from_soup(cls, soup: Tag, server: str = "") -> List["Pengguna"]:
        lis: List[Tag] = soup.findAll("li")
        results: List["Pengguna"] = list()
        for li in lis[1:-1]:
            results.append(cls.from_li(li, server))
        return results



from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from dapodik import Dapodik


class BaseProp(object):
    @property
    def dapodik(self) -> "Dapodik":
        return getattr(self, "_dapodik")  # type: ignore



from datetime import datetime
from typing import Optional

import attr


@attr.dataclass(frozen=True, slots=True)
class RolePengguna:
    id_role_pengguna: str
    sekolah_id: str
    lembaga_id: Optional[str]
    yayasan_id: Optional[str]
    la_id: Optional[str]
    dudi_id: Optional[str]
    kode_lemb_sert: Optional[str]
    pengguna_id: str
    peran_id: Optional[int]
    sk_penugasan: Optional[str]
    tgl_sk_penugasan: Optional[str]
    approval_peran: str
    tgl_kadaluwarsa: Optional[str]
    last_active: Optional[str]
    jenis_lembaga: str
    create_date: datetime
    last_update: datetime
    expired_date: Optional[datetime]
    last_sync: datetime
    pengguna_id_str: str



from datetime import datetime, date

import attr


@attr.dataclass(frozen=True, slots=True)
class JurusanSp:
    jurusan_sp_id: str
    sekolah_id: str
    kebutuhan_khusus_id: int
    jurusan_id: int
    nama_jurusan_sp: str
    sk_izin: str
    tanggal_sk_izin: date
    create_date: datetime
    last_update: datetime
    soft_delete: str
    last_sync: datetime
    updater_id: str
    sekolah_id_str: str
    kebutuhan_khusus_id_str: str
    jurusan_id_str: str
    vld_count: int



import attr
from datetime import datetime
from typing import Optional

from dapodik.base import BaseProp


@attr.dataclass(frozen=True, slots=True)
class KeahlianLaboratorium:
    keahlian_laboratorium_id: int
    nama: str
    create_date: datetime
    last_update: datetime
    expired_date: Optional[datetime]
    last_sync: datetime

    def __str__(self):
        return self.nama

    class Prop(BaseProp):
        @property
        def keahlian_laboratorium(self) -> "KeahlianLaboratorium":
            return self.dapodik._find(
                self.dapodik.keahlian_laboratorium(),
                lambda x: x.keahlian_laboratorium_id
                == getattr(self, "keahlian_laboratorium_id"),
            )

        @keahlian_laboratorium.setter
        def keahlian_laboratorium(self, value: "KeahlianLaboratorium"):
            new = self.dapodik._find(
                self.dapodik.keahlian_laboratorium(),
                lambda x: x.keahlian_laboratorium_id == value.keahlian_laboratorium_id,
            )
            setattr(self, "keahlian_laboratorium_id", new.keahlian_laboratorium_id)



from .validasi import (
    Validasi,
    ValidasiSekolah,
    ValidasiPrasarana,
    ValidasiPesertaDidik,
    ValidasiPtk,
    ValidasiRombonganBelajar,
    ValidasiPembelajaran,
    ValidasiNilai,
    ValidasiReferensi,
)

from .base import BaseValidasi


__all__ = [
    "Validasi",
    "ValidasiSekolah",
    "ValidasiPrasarana",
    "ValidasiPesertaDidik",
    "ValidasiPtk",
    "ValidasiRombonganBelajar",
    "ValidasiPembelajaran",
    "ValidasiNilai",
    "ValidasiReferensi",
    "BaseValidasi",
]



from datetime import datetime
from typing import Optional

import attr


@attr.dataclass
class RuangLongitudinal:
    id_ruang: str
    semester_id: str
    blob_id: Optional[str]
    rusak_lisplang_talang: str
    ket_lisplang_talang: str
    rusak_rangka_plafon: str
    ket_rangka_plafon: str
    rusak_tutup_plafon: str
    ket_tutup_plafon: str
    rusak_bata_dinding: str
    ket_bata_dinding: str
    rusak_plester_dinding: str
    ket_plester_dinding: str
    rusak_daun_jendela: str
    ket_daun_jendela: str
    rusak_daun_pintu: str
    ket_daun_pintu: str
    rusak_kusen: str
    ket_kusen: str
    rusak_tutup_lantai: str
    ket_penutup_lantai: str
    rusak_inst_listrik: str
    ket_inst_listrik: str
    rusak_inst_air: str
    ket_inst_air: str
    rusak_drainase: str
    ket_drainase: str
    rusak_finish_struktur: str
    ket_finish_struktur: str
    rusak_finish_plafon: str
    ket_finish_plafon: str
    rusak_finish_dinding: str
    ket_finish_dinding: str
    rusak_finish_kpj: str
    ket_finish_kpj: str
    berfungsi: str
    id_ruang_str: str
    semester_id_str: str
    ruang_longitudinal_id: str
    create_date: Optional[datetime] = None
    last_update: Optional[datetime] = None
    soft_delete: Optional[str] = None
    last_sync: Optional[datetime] = None
    updater_id: Optional[str] = None



from datetime import datetime
from typing import Optional

import attr


@attr.dataclass
class Sanitasi:
    sekolah_id: str
    semester_id: str
    sumber_air_id: str
    sumber_air_minum_id: str
    ketersediaan_air: str
    kecukupan_air: str
    minum_siswa: str
    memproses_air: str
    siswa_bawa_air: str
    toilet_siswa_laki: str
    toilet_siswa_perempuan: str
    toilet_siswa_kk: str
    toilet_siswa_kecil: str
    jml_jamban_l_g: str
    jml_jamban_l_tg: str
    jml_jamban_p_g: str
    jml_jamban_p_tg: str
    jml_jamban_lp_g: str
    jml_jamban_lp_tg: str
    tempat_cuci_tangan: str
    tempat_cuci_tangan_rusak: str
    a_sabun_air_mengalir: str
    jamban_difabel: str
    tipe_jamban: str
    a_sedia_pembalut: str
    kegiatan_cuci_tangan: Optional[str]
    pembuangan_air_limbah: Optional[str]
    a_kuras_septitank: Optional[str]
    a_memiliki_solokan: Optional[str]
    a_tempat_sampah_kelas: str
    a_tempat_sampah_tutup_p: str
    a_cermin_jamban_p: str
    a_memiliki_tps: str
    a_tps_angkut_rutin: str
    a_anggaran_sanitasi: str
    a_melibatkan_sanitasi_siswa: str
    a_kemitraan_san_daerah: Optional[str]
    a_kemitraan_san_puskesmas: Optional[str]
    a_kemitraan_san_swasta: Optional[str]
    a_kemitraan_san_non_pem: Optional[str]
    kie_guru_cuci_tangan: Optional[str]
    kie_guru_haid: Optional[str]
    kie_guru_perawatan_toilet: Optional[str]
    kie_guru_keamanan_pangan: Optional[str]
    kie_guru_minum_air: Optional[str]
    kie_kelas_cuci_tangan: Optional[str]
    kie_kelas_haid: Optional[str]
    kie_kelas_perawatan_toilet: Optional[str]
    kie_kelas_keamanan_pangan: Optional[str]
    kie_kelas_minum_air: Optional[str]
    kie_toilet_cuci_tangan: Optional[str]
    kie_toilet_haid: Optional[str]
    kie_toilet_perawatan_toilet: Optional[str]
    kie_toilet_keamanan_pangan: Optional[str]
    kie_toilet_minum_air: Optional[str]
    kie_selasar_cuci_tangan: Optional[str]
    kie_selasar_haid: Optional[str]
    kie_selasar_perawatan_toilet: Optional[str]
    kie_selasar_keamanan_pangan: Optional[str]
    kie_selasar_minum_air: Optional[str]
    kie_uks_cuci_tangan: Optional[str]
    kie_uks_haid: Optional[str]
    kie_uks_perawatan_toilet: Optional[str]
    kie_uks_keamanan_pangan: Optional[str]
    kie_uks_minum_air: Optional[str]
    kie_kantin_cuci_tangan: Optional[str]
    kie_kantin_haid: Optional[str]
    kie_kantin_perawatan_toilet: Optional[str]
    kie_kantin_keamanan_pangan: Optional[str]
    kie_kantin_minum_air: Optional[str]
    create_date: datetime
    last_update: datetime
    soft_delete: str
    last_sync: datetime
    updater_id: str
    sekolah_id_str: str
    semester_id_str: str
    sanitasi_id: str



import attr
from datetime import datetime
from typing import Optional

from dapodik.base import BaseProp


@attr.dataclass(frozen=True, slots=True)
class JenisKeluar:
    jenis_keluar_id: int
    ket_keluar: str
    keluar_pd: str
    keluar_ptk: str
    create_date: datetime
    last_update: datetime
    expired_date: Optional[datetime]
    last_sync: datetime

    def __str__(self):
        return self.ket_keluar

    class Prop(BaseProp):
        @property
        def jenis_keluar(self) -> Optional["JenisKeluar"]:
            try:
                return self.dapodik._find(
                    self.dapodik.jenis_keluar(),
                    lambda x: x.jenis_keluar_id == getattr(self, "jenis_keluar_id"),
                )
            except ValueError:
                return None

        @jenis_keluar.setter
        def jenis_keluar(self, value: "JenisKeluar"):
            new_jenis_keluar = self.dapodik._find(
                self.dapodik.jenis_keluar(),
                lambda x: x.jenis_keluar_id == value.jenis_keluar_id,
            )
            setattr(self, "jenis_keluar_id", new_jenis_keluar.jenis_keluar_id)



import attr
from datetime import date, datetime
from typing import Optional
from uuid import UUID

from dapodik.gtk.enums import PtkAktif


@attr.dataclass(slots=True)
class PtkTerdaftar:
    ptk_terdaftar_id: UUID
    ptk_id: UUID
    sekolah_id: UUID
    jenis_keluar_id: Optional[int]
    tahun_ajaran_id: str
    nomor_surat_tugas: str
    tanggal_surat_tugas: date
    ptk_induk: int
    tmt_tugas: date
    aktif_bulan_01: PtkAktif
    aktif_bulan_02: PtkAktif
    aktif_bulan_03: PtkAktif
    aktif_bulan_04: PtkAktif
    aktif_bulan_05: PtkAktif
    aktif_bulan_06: PtkAktif
    aktif_bulan_07: PtkAktif
    aktif_bulan_08: PtkAktif
    aktif_bulan_09: PtkAktif
    aktif_bulan_10: PtkAktif
    aktif_bulan_11: PtkAktif
    aktif_bulan_12: PtkAktif
    tgl_ptk_keluar: Optional[date]
    create_date: Optional[datetime] = None
    last_update: Optional[datetime] = None
    soft_delete: int = 0
    last_sync: Optional[datetime] = None
    updater_id: Optional[UUID] = None
    ptk_id_str: Optional[str] = None
    sekolah_id_str: Optional[str] = None
    tahun_ajaran_id_str: Optional[str] = None



from enum import Enum


class JenisKelamin(Enum):
    LAKI_LAKI = "L"
    PEREMPUAN = "P"

    def __str__(self) -> str:
        if self.value == "L":
            return "Laki-laki"
        elif self.value == "P":
            return "Perempuan"
        return "Tidak terdefinisi"



from datetime import datetime
from uuid import UUID

import attr


@attr.dataclass(frozen=True, slots=True)
class AnggotaRombel:
    anggota_rombel_id: UUID
    rombongan_belajar_id: UUID
    peserta_didik_id: UUID
    jenis_pendaftaran_id: int
    create_date: datetime
    last_update: datetime
    soft_delete: int
    last_sync: datetime
    updater_id: UUID



import attr
from datetime import datetime, date
from typing import List, Optional, TYPE_CHECKING
from uuid import UUID

if TYPE_CHECKING:
    from dapodik import Dapodik
from dapodik.rest import Agama


@attr.dataclass
class PesertaDidik(Agama.Prop):
    peserta_didik_id: UUID
    nama: str
    jenis_kelamin: str
    nisn: str
    nik: str
    no_kk: str
    tempat_lahir: str
    tanggal_lahir: date
    agama_id: int
    kebutuhan_khusus_id: int
    alamat_jalan: str
    rt: int
    rw: int
    nama_dusun: str
    desa_kelurahan: str
    kode_wilayah: str
    kode_pos: Optional[int]
    lintang: str
    bujur: str
    jenis_tinggal_id: int
    alat_transportasi_id: int
    nik_ayah: str
    nik_ibu: str
    anak_keberapa: int
    nik_wali: Optional[str]
    nomor_telepon_rumah: Optional[str]
    nomor_telepon_seluler: Optional[str]
    email: Optional[str]
    penerima_kps: int
    no_kps: Optional[str]
    layak_pip: int
    penerima_kip: int
    no_kip: Optional[str]
    nm_kip: Optional[str]
    no_kks: Optional[str]
    reg_akta_lahir: str
    id_layak_pip: Optional[int]
    id_bank: Optional[int]
    rekening_bank: Optional[str]
    nama_kcp: Optional[str]
    rekening_atas_nama: Optional[str]
    status_data: Optional[int]
    nama_ayah: str
    tahun_lahir_ayah: int
    jenjang_pendidikan_ayah: int
    pekerjaan_id_ayah: int
    penghasilan_id_ayah: int
    kebutuhan_khusus_id_ayah: int
    nama_ibu_kandung: str
    tahun_lahir_ibu: int
    jenjang_pendidikan_ibu: int
    penghasilan_id_ibu: int
    pekerjaan_id_ibu: int
    kebutuhan_khusus_id_ibu: int
    nama_wali: Optional[str]
    tahun_lahir_wali: int
    jenjang_pendidikan_wali: int
    pekerjaan_id_wali: int
    penghasilan_id_wali: int
    kewarganegaraan: str
    registrasi_id: UUID
    jurusan_sp_id: Optional[str]
    sekolah_id: UUID
    jenis_pendaftaran_id: int
    nipd: int
    tanggal_masuk_sekolah: date
    jenis_keluar_id: Optional[int]
    tanggal_keluar: Optional[datetime]
    keterangan: str
    no_skhun: Optional[str]
    no_peserta_ujian: Optional[str]
    no_seri_ijazah: Optional[str]
    a_pernah_paud: int
    a_pernah_tk: int
    sekolah_asal: Optional[str]
    id_hobby: int
    id_cita: int
    nama_sorter: str
    jenis_pendaftaran_id_str: str
    ket_keluar: Optional[str]
    anggota_rombel_id: Optional[UUID]
    tingkat_pendidikan_id: Optional[int]
    rombel_saat_ini: str
    rombel: str
    id_bank_str: Optional[str]
    kewarganegaraan_str: str
    nomor_induk_pd: int
    yatim_piatu: bool
    konfirmasi_mutasi: int
    vld_count: Optional[int]
    # Metadata
    create_date: Optional[datetime] = None
    last_update: Optional[datetime] = None
    soft_delete: Optional[int] = None
    last_sync: Optional[datetime] = None
    updater_id: Optional[UUID] = None
    _dapodik: Optional["Dapodik"] = None

    def __str__(self):
        return self.nama

    @attr.dataclass(kw_only=True)
    class Create:
        nama: str
        jenis_kelamin: str
        nisn: str = ""
        nik: str
        tempat_lahir: str
        tanggal_lahir: datetime
        nama_ibu_kandung: str
        sekolah_id: UUID
        pdb_id: UUID
        kewarganegaraan: str
        tahun_lahir_ayah: int
        tahun_lahir_ibu: int
        tahun_lahir_wali: int
        vld_count: int = 0
        peserta_didik_id: str = "Admin.model.PesertaDidik-1"
        kewarganegaraan_str: str
        no_kk: str
        reg_akta_lahir: str = ""
        agama_id: int
        agama_id_str: str = ""
        kebutuhan_khusus_id: int = 0
        kebutuhan_khusus_id_str: str = ""
        alamat_jalan: str
        rt: int = 0
        rw: int = 0
        nama_dusun: str
        desa_kelurahan: str
        kode_wilayah: str
        kode_wilayah_str: str
        kode_pos: int
        lintang: int
        bujur: int
        jenis_tinggal_id: int
        jenis_tinggal_id_str: str
        alat_transportasi_id: int
        alat_transportasi_id_str: str = ""
        no_kks: str = ""
        anak_keberapa: int = 1
        penerima_kps: int = 0
        no_kps: str = ""
        penerima_kip: int = 0
        no_kip: str = ""
        layak_pip: int = 0
        id_layak_pip: Optional[int] = None
        id_layak_pip_str: str
        id_bank: str = ""
        id_bank_str: str = ""
        rekening_bank: str = ""
        nama_kcp: str = ""
        rekening_atas_nama: str = ""
        status_data: int = 0
        nama_ayah: str
        nik_ayah: str
        jenjang_pendidikan_ayah: int
        jenjang_pendidikan_ayah_str: str
        pekerjaan_id_ayah: int
        pekerjaan_id_ayah_str: str
        penghasilan_id_ayah: int
        penghasilan_id_ayah_str: str
        kebutuhan_khusus_id_ayah: int = 0
        kebutuhan_khusus_id_ayah_str: str = ""
        nik_ibu: str
        jenjang_pendidikan_ibu: int
        jenjang_pendidikan_ibu_str: str = ""
        pekerjaan_id_ibu: int
        pekerjaan_id_ibu_str: str = ""
        penghasilan_id_ibu: int
        penghasilan_id_ibu_str: str = ""
        kebutuhan_khusus_id_ibu: int = 0
        kebutuhan_khusus_id_ibu_str: str = ""
        nm_kip: int = 0
        nama_wali: str = ""
        nik_wali: str = ""
        jenjang_pendidikan_wali: int = 0
        jenjang_pendidikan_wali_str: str = ""
        pekerjaan_id_wali: int = 0
        pekerjaan_id_wali_str: str = ""
        penghasilan_id_wali: int = 0
        penghasilan_id_wali_str: str = ""
        nomor_telepon_rumah: str = ""
        nomor_telepon_seluler: str = ""
        email: str = ""
        kebutuhan_khusus_id_selector: List[int] = attr.ib(factory=list)
        kebutuhan_khusus_id_selector_ayah: List[int] = attr.ib(factory=list)
        kebutuhan_khusus_id_selector_ibu: List[int] = attr.ib(factory=list)



from datetime import datetime

import attr


@attr.dataclass
class AkreditasiSp:
    akred_sp_id: str
    sekolah_id: str
    akred_sp_sk: str
    akred_sp_tmt: str
    akred_sp_tst: str
    akreditasi_id: str
    la_id: str
    create_date: datetime
    last_update: datetime
    soft_delete: str
    last_sync: datetime
    updater_id: str
    sekolah_id_str: str
    la_id_str: str



import attr
from datetime import datetime
from typing import Optional

from dapodik.base import BaseProp


@attr.dataclass(frozen=True, slots=True)
class Jurusan:
    jurusan_id: int
    nama_jurusan: str
    untuk_sma: str
    untuk_smk: str
    untuk_pt: str
    untuk_slb: str
    untuk_smklb: str
    jurusan_induk: Optional[str]
    level_bidang_id: str
    create_date: datetime
    last_update: datetime
    expired_date: Optional[datetime]
    last_sync: datetime

    @property
    def level_bidang(self):
        # TODO API
        return self.level_bidang_id

    def __str__(self):
        return self.nama_jurusan

    class Prop(BaseProp):
        @property
        def jurusan(self) -> "Jurusan":
            return self.dapodik._find(
                self.dapodik.jurusan(),
                lambda x: x.jurusan_id == getattr(self, "jurusan_id"),
            )

        @jurusan.setter
        def jurusan(self, value: "Jurusan"):
            new = self.dapodik._find(
                self.dapodik.jurusan(),
                lambda x: x.jurusan_id == value.jurusan_id,
            )
            setattr(self, "jurusan_id", new.jurusan_id)



import attr
from datetime import datetime
from typing import Optional

from dapodik.base import BaseProp


@attr.dataclass(frozen=True, slots=True)
class JenisHobby:
    id_hobby: int
    nm_hobby: str
    create_date: datetime
    last_update: datetime
    expired_date: Optional[datetime]
    last_sync: datetime

    def __str__(self):
        return self.nm_hobby

    class Prop(BaseProp):
        @property
        def jenis_hobby(self) -> "JenisHobby":
            return self.dapodik._find(
                self.dapodik.jenis_hobby(),
                lambda x: x.id_hobby == getattr(self, "id_hobby"),
            )

        @jenis_hobby.setter
        def jenis_hobby(self, value: "JenisHobby"):
            new_jenis_hobby = self.dapodik._find(
                self.dapodik.jenis_hobby(),
                lambda x: x.id_hobby == value.id_hobby,
            )
            setattr(self, "id_hobby", new_jenis_hobby.id_hobby)



from enum import Enum


class PtkInduk(Enum):
    INDUK = "1"
    NON_INDUK = "0"

    def __bool__(self):
        return self.value == "1"


class PtkAktif(Enum):
    AKTIF = "1"
    NON_AKTIF = "0"

    def __bool__(self):
        return self.value == "1"



from .anggota_rombel import AnggotaRombel
from .pembelajaran import Pembelajaran
from .rombel_portal import RombelPortal
from .rombongan_belajar import RombonganBelajar

from .base import BaseRombonganBelajar


__all__ = [
    "AnggotaRombel",
    "Pembelajaran",
    "RombelPortal",
    "RombonganBelajar",
    "BaseRombonganBelajar",
]



import attr


@attr.dataclass
class Validasi:
    validasi_id: int
    table: str
    tipe: int
    keterangan: str

    def __str__(self) -> str:
        return self.keterangan


class ValidasiSekolah(Validasi):
    pass


class ValidasiPrasarana(Validasi):
    pass


class ValidasiPesertaDidik(Validasi):
    pass


class ValidasiPtk(Validasi):
    pass


class ValidasiRombonganBelajar(Validasi):
    pass


class ValidasiPembelajaran(Validasi):
    pass


class ValidasiNilai(Validasi):
    pass


class ValidasiReferensi(Validasi):
    pass



import attr


@attr.dataclass
class Pembelajaran:
    rombongan_belajar_id: str
    status_di_kurikulum_str: str
    mata_pelajaran_id: int
    nama_mata_pelajaran: str
    sk_mengajar: str
    ptk_terdaftar_id: str
    tanggal_sk_mengajar: str
    jam_mengajar_per_minggu: int
    induk_pembelajaran_id: str = ""
    status_di_kurikulum: int = 9
    semester_id: str = "20201"
    pembelajaran_id: str = "Admin.model.PembelajaranNew-1"



import attr
from datetime import date, datetime
from typing import Any, Optional
from uuid import UUID

from dapodik.enums import JenisKelamin
from dapodik.gtk.enums import PtkAktif, PtkInduk


@attr.dataclass(slots=True)
class Ptk:
    ptk_terdaftar_id: UUID
    ptk_id: UUID
    sekolah_id: UUID
    jenis_keluar_id: Optional[int]
    tahun_ajaran_id: str
    nomor_surat_tugas: str
    tanggal_surat_tugas: date
    ptk_induk: PtkInduk
    tmt_tugas: date
    aktif_bulan_01: PtkAktif
    aktif_bulan_02: PtkAktif
    aktif_bulan_03: PtkAktif
    aktif_bulan_04: PtkAktif
    aktif_bulan_05: PtkAktif
    aktif_bulan_06: PtkAktif
    aktif_bulan_07: PtkAktif
    aktif_bulan_08: PtkAktif
    aktif_bulan_09: PtkAktif
    aktif_bulan_10: PtkAktif
    aktif_bulan_11: PtkAktif
    aktif_bulan_12: PtkAktif
    tgl_ptk_keluar: Optional[date]
    jenis_keluar_id_str: Optional[str]
    nama: str
    nip: Optional[str]
    jenis_kelamin: JenisKelamin
    tempat_lahir: str
    tanggal_lahir: date
    nik: Optional[str]
    no_kk: Optional[str]
    niy_nigk: Optional[str]
    nuptk: Optional[str]
    nuks: Optional[str]
    status_kepegawaian_id: int
    jenis_ptk_id: int
    pengawas_bidang_studi_id: Optional[int]
    agama_id: int
    alamat_jalan: Optional[str]
    rt: str
    rw: str
    nama_dusun: Optional[str]
    desa_kelurahan: str
    kode_wilayah: str
    kode_pos: Optional[str]
    lintang: Optional[str]
    bujur: Optional[str]
    no_telepon_rumah: Optional[str]
    no_hp: Optional[str]
    email: Optional[str]
    status_keaktifan_id: int
    sk_cpns: Optional[str]
    tgl_cpns: Optional[date]
    sk_pengangkatan: str
    tmt_pengangkatan: date
    lembaga_pengangkat_id: int
    pangkat_golongan_id: int
    keahlian_laboratorium_id: int
    sumber_gaji_id: int
    nama_ibu_kandung: str
    status_perkawinan: int
    nama_suami_istri: Optional[str]
    nip_suami_istri: Optional[str]
    pekerjaan_suami_istri: int
    tmt_pns: Optional[date]
    sudah_lisensi_kepala_sekolah: int
    jumlah_sekolah_binaan: Optional[int]
    pernah_diklat_kepengawasan: int
    nm_wp: Optional[str]
    status_data: Optional[int]
    karpeg: Optional[Any]
    karpas: Optional[Any]
    mampu_handle_kk: int
    keahlian_braille: int
    keahlian_bhs_isyarat: int
    npwp: Optional[str]
    kewarganegaraan: str
    id_bank: Optional[int]
    rekening_bank: Optional[str]
    rekening_atas_nama: Optional[str]
    pengguna_id: Optional[UUID] = None
    username: Optional[str] = None
    password: Optional[str] = None
    jabatan_lembaga: Optional[str] = None
    verifikasi_email: Optional[bool] = None
    jenis_ptk_id_str: Optional[str] = None
    blob_id: Optional[str] = None
    vld_count: int = 0
    create_date: Optional[datetime] = None
    last_update: Optional[datetime] = None
    soft_delete: Optional[int] = None
    last_sync: Optional[datetime] = None
    updater_id: Optional[UUID] = None



import attr
from datetime import datetime
from typing import Optional

from dapodik.base import BaseProp


@attr.dataclass(frozen=True, slots=True)
class KategoriTk:
    kategori_tk_id: int
    nama: str
    create_date: datetime
    last_update: datetime
    expired_date: Optional[datetime]
    last_sync: datetime

    def __str__(self):
        return self.nama

    class Prop(BaseProp):
        @property
        def kategori_tk(self) -> "KategoriTk":
            return self.dapodik._find(
                self.dapodik.kategori_tk(),
                lambda x: x.kategori_tk_id == getattr(self, "kategori_tk_id"),
            )

        @kategori_tk.setter
        def kategori_tk(self, value: "KategoriTk"):
            new = self.dapodik._find(
                self.dapodik.kategori_tk(),
                lambda x: x.kategori_tk_id == value.kategori_tk_id,
            )
            setattr(self, "kategori_tk_id", new.kategori_tk_id)



import attr
from datetime import datetime
from typing import Optional

from dapodik.base import BaseProp


@attr.dataclass(frozen=True, slots=True)
class JenisCita:
    id_cita: int
    nm_cita: str
    create_date: datetime
    last_update: datetime
    expired_date: Optional[datetime]
    last_sync: datetime

    def __str__(self):
        return self.nm_cita

    class Prop(BaseProp):
        @property
        def cita(self) -> "JenisCita":
            return self.dapodik._find(
                self.dapodik.jenis_cita(),
                lambda x: x.id_cita == getattr(self, "id_cita"),
            )

        @cita.setter
        def cita(self, value: "JenisCita"):
            new_id_cita = self.dapodik._find(
                self.dapodik.jenis_cita(),
                lambda x: x.id_cita == value.id_cita,
            )
            setattr(self, "id_cita", new_id_cita.id_cita)



from datetime import datetime
from typing import Optional

import attr


@attr.dataclass
class BangunanLongitudinal:
    id_bangunan: str
    semester_id: str
    rusak_pondasi: str
    ket_pondasi: str
    rusak_sloop_kolom_balok: str
    ket_sloop_kolom_balok: str
    rusak_plester_struktur: str
    ket_plester_struktur: str
    rusak_kudakuda_atap: str
    ket_kudakuda_atap: str
    rusak_kaso_atap: str
    ket_kaso_atap: str
    rusak_reng_atap: str
    ket_reng_atap: str
    rusak_tutup_atap: str
    ket_tutup_atap: str
    nilai_saat_ini: str
    id_bangunan_str: str
    semester_id_str: str
    bangunan_longitudinal_id: str
    bangunan_longitudinal_id_str: str = ""
    create_date: Optional[datetime] = None
    last_update: Optional[datetime] = None
    soft_delete: Optional[str] = None
    last_sync: Optional[datetime] = None
    updater_id: Optional[str] = None



from .peserta_didik_baru import PesertaDidikBaru
from .peserta_didik_longitudinal import PesertaDidikLongitudinal
from .registrasi_peserta_didik import RegistrasiPesertaDidik
from .peserta_didik import PesertaDidik

from .base import BasePesertaDidik


__all__ = [
    "PesertaDidikBaru",
    "PesertaDidikLongitudinal",
    "RegistrasiPesertaDidik",
    "PesertaDidik",
    "BasePesertaDidik",
]



import attr
from datetime import datetime
from typing import Optional

from dapodik.base import BaseProp


@attr.dataclass(frozen=True, slots=True)
class Bank:
    id_bank: str
    nm_bank: str
    create_date: datetime
    last_update: datetime
    expired_date: Optional[datetime]
    last_sync: datetime

    def __str__(self):
        return self.nm_bank

    class Prop(BaseProp):
        @property
        def bank(self) -> "Bank":
            return self.dapodik._find(
                self.dapodik.bank(),
                lambda x: x.id_bank == getattr(self, "id_bank"),
            )

        @bank.setter
        def bank(self, value: "Bank"):
            new_bank = self.dapodik._find(
                self.dapodik.bank(),
                lambda x: x.id_bank == value.id_bank,
            )
            setattr(self, "id_bank", new_bank.id_bank)



import attr
import cattr
import json


@attr.dataclass(frozen=True, slots=True)
class DapodikMessage:
    success: bool = True
    message: str = ""

    @classmethod
    def from_str(cls, obj: str) -> "DapodikMessage":
        obj = obj.replace("'", '"')
        data = json.loads(obj)
        return cattr.structure(data, cls)



from datetime import datetime
from typing import Optional

import attr


@attr.dataclass
class BlockGrant:
    blockgrant_id: str
    sekolah_id: str
    nama: str
    tahun: str
    jenis_bantuan_id: int
    sumber_dana_id: str
    besar_bantuan: str
    dana_pendamping: str
    peruntukan_dana: Optional[str]
    asal_data: str
    create_date: datetime
    last_update: datetime
    soft_delete: str
    last_sync: datetime
    updater_id: str
    sekolah_id_str: str
    jenis_bantuan_id_str: str
    sumber_dana_id_str: str



from dapodik.base import BaseDapodik
from typing import List

from . import Sekolah


class BaseSekolah(BaseDapodik):
    def sekolah(self, index: int = 0) -> Sekolah:
        return self._get_rows("/rest/Sekolah", List[Sekolah])[index]



import attr
from datetime import datetime
from typing import Optional

from dapodik.base import BaseProp


@attr.dataclass(frozen=True, slots=True)
class Agama:
    agama_id: int
    nama: str
    create_date: datetime
    last_update: datetime
    expired_date: Optional[datetime]
    last_sync: datetime

    def __str__(self):
        return self.nama

    class Prop(BaseProp):
        @property
        def agama(self) -> "Agama":
            return self.dapodik._find(
                self.dapodik.agama(), lambda x: x.agama_id == getattr(self, "agama_id")
            )

        @agama.setter
        def agama(self, value: "Agama"):
            new_agama = self.dapodik._find(
                self.dapodik.agama(), lambda x: x.agama_id == value.agama_id
            )
            setattr(self, "agama_id", new_agama.agama_id)



from datetime import datetime
from typing import Optional

import attr


@attr.dataclass
class Buku:
    id_buku: str
    mata_pelajaran_id: int
    id_ruang: Optional[str]
    sekolah_id: str
    id_biblio: Optional[str]
    tingkat_pendidikan_id: str
    nm_buku: str
    id_hapus_buku: Optional[str]
    tgl_hapus_buku: Optional[str]
    asal_data: str
    mata_pelajaran_id_str: str
    sekolah_id_str: str
    create_date: Optional[datetime] = None
    last_update: Optional[datetime] = None
    soft_delete: Optional[str] = None
    last_sync: Optional[datetime] = None
    updater_id: Optional[str] = None



import attr
from datetime import datetime
from typing import Optional

from dapodik.base import BaseProp


@attr.dataclass(frozen=True, slots=True)
class JenisHapusBuku:
    id_hapus_buku: int
    ket_hapus_buku: str
    u_prasarana: str
    u_sarana: str
    create_date: datetime
    last_update: datetime
    expired_date: Optional[datetime]
    last_sync: datetime

    def __str__(self):
        return self.ket_hapus_buku

    class Prop(BaseProp):
        @property
        def jenis_hapus_buku(self) -> "JenisHapusBuku":
            return self.dapodik._find(
                self.dapodik.jenis_hapus_buku(),
                lambda x: x.id_hapus_buku == getattr(self, "id_hapus_buku"),
            )

        @jenis_hapus_buku.setter
        def jenis_hapus_buku(self, value: "JenisHapusBuku"):
            new_hapus_buku = self.dapodik._find(
                self.dapodik.jenis_hapus_buku(),
                lambda x: x.id_hapus_buku == value.id_hapus_buku,
            )
            setattr(self, "id_hapus_buku", new_hapus_buku.id_hapus_buku)



from datetime import datetime

import attr


@attr.dataclass
class Kepanitiaan:
    id_panitia: str
    sekolah_id: str
    id_jns_panitia: int
    nm_panitia: str
    instansi: str
    tkt_panitia: str
    sk_tugas: str
    tmt_sk_tugas: str
    tst_sk_tugas: str
    a_pasang_papan: str
    a_formulir: str
    a_silabus: str
    a_berlaku_pos: str
    a_sosialisasi_pos: str
    a_ks_edukatif: str
    create_date: datetime
    last_update: datetime
    soft_delete: str
    last_sync: datetime
    updater_id: str
    sekolah_id_str: str
    id_jns_panitia_str: str



from datetime import datetime
from typing import Optional

import attr


@attr.dataclass
class TanahDariBlockgrant:
    blockgrant_id: str
    blockgrant_id_str: str
    id_tanah: str
    id_tanah_str: str = ""
    tanah_dari_blockgrant_id: str = "Admin.model.TanahDariBlockgrant-1"
    create_date: Optional[datetime] = None
    last_update: Optional[datetime] = None
    soft_delete: Optional[str] = None
    last_sync: Optional[datetime] = None
    updater_id: Optional[str] = None



import attr
from functools import partial


def frozen(_, __, ___):
    """
    Prevent an attribute to be modified.

    .. versionadded:: 20.1.0
    """
    raise attr.exceptions.FrozenAttributeError("Atribut tidak dapat dirubah")


frozen_attrib = partial(attr.ib, on_setattr=frozen)



from datetime import datetime
from typing import Optional

import attr


@attr.dataclass
class Yayasan:
    yayasan_id: str
    nama: str
    alamat_jalan: str
    rt: str
    rw: str
    nama_dusun: str
    desa_kelurahan: str
    kode_wilayah: str
    kode_pos: str
    lintang: str
    bujur: str
    nomor_telepon: Optional[str]
    nomor_fax: Optional[str]
    email: Optional[str]
    website: Optional[str]
    npyp: Optional[str]
    nama_pimpinan_yayasan: str
    no_pendirian_yayasan: str
    tanggal_pendirian_yayasan: str
    nomor_pengesahan_pn_ln: Optional[str]
    nomor_sk_bn: Optional[str]
    tanggal_sk_bn: str
    create_date: datetime
    last_update: datetime
    soft_delete: str
    last_sync: datetime
    updater_id: str
    kode_wilayah_str: str
    vld_count: int



from datetime import datetime
from typing import Optional

import attr


@attr.dataclass
class Bangunan:
    id_bangunan: str
    jenis_prasarana_id: int
    sekolah_id: str
    id_tanah: str
    ptk_id: Optional[str]
    id_hapus_buku: Optional[str]
    kepemilikan_sarpras_id: str
    kd_kl: Optional[str]
    kd_satker: Optional[str]
    kd_brg: Optional[str]
    nup: Optional[str]
    kode_eselon1: Optional[str]
    nama_eselon1: Optional[str]
    kode_sub_satker: Optional[str]
    nama_sub_satker: Optional[str]
    nama: str
    panjang: Optional[int]
    lebar: Optional[int]
    nilai_perolehan_aset: Optional[str]
    jml_lantai: str
    thn_dibangun: Optional[str]
    luas_tapak_bangunan: Optional[str]
    vol_pondasi_m3: Optional[str]
    vol_sloop_kolom_balok_m3: Optional[str]
    panj_kudakuda_m: Optional[str]
    vol_kudakuda_m3: Optional[str]
    panj_kaso_m: Optional[str]
    panj_reng_m: Optional[str]
    luas_tutup_atap_m2: Optional[str]
    kd_satker_tanah: Optional[str]
    nm_satker_tanah: Optional[str]
    kd_brg_tanah: Optional[str]
    nm_brg_tanah: Optional[str]
    nup_brg_tanah: Optional[str]
    tgl_sk_pemakai: str
    tgl_hapus_buku: Optional[str]
    ket_bangunan: Optional[str]
    asal_data: str
    jenis_prasarana_id_str: str
    id_tanah_str: str
    sekolah_id_str: str
    vld_count: int
    create_date: Optional[datetime] = None
    last_update: Optional[datetime] = None
    soft_delete: Optional[str] = None
    last_sync: Optional[datetime] = None
    updater_id: Optional[str] = None



import attr
from datetime import datetime
from typing import Optional

from dapodik.base import BaseProp


@attr.dataclass(frozen=True, slots=True)
class Akreditasi:
    akreditasi_id: int
    nama: str
    create_date: datetime
    last_update: datetime
    expired_date: Optional[datetime]
    last_sync: datetime

    def __str__(self):
        return self.nama

    class Prop(BaseProp):
        @property
        def akreditasi(self) -> "Akreditasi":
            return self.dapodik._find(
                self.dapodik.akreditasi(),
                lambda x: x.akreditasi_id == getattr(self, "akreditasi_id"),
            )

        @akreditasi.setter
        def akreditasi(self, value: "Akreditasi"):
            new_akreditasi = self.dapodik._find(
                self.dapodik.akreditasi(),
                lambda x: x.akreditasi_id == value.akreditasi_id,
            )
            setattr(self, "akreditasi_id", new_akreditasi.akreditasi_id)



import attr
from datetime import datetime
from typing import Optional

from dapodik.base import BaseProp


@attr.dataclass(frozen=True, slots=True)
class FasilitasLayanan:
    fasilitas_layanan_id: int
    nama: str
    create_date: datetime
    last_update: datetime
    expired_date: Optional[datetime]
    last_sync: datetime

    def __str__(self):
        return self.nama

    class Prop(BaseProp):
        @property
        def fasilitas_layanan(self) -> "FasilitasLayanan":
            return self.dapodik._find(
                self.dapodik.fasilitas_layanan(),
                lambda x: x.fasilitas_layanan_id
                == getattr(self, "fasilitas_layanan_id"),
            )

        @fasilitas_layanan.setter
        def fasilitas_layanan(self, value: "FasilitasLayanan"):
            new_fasilitas_layanan = self.dapodik._find(
                self.dapodik.fasilitas_layanan(),
                lambda x: x.fasilitas_layanan_id == value.fasilitas_layanan_id,
            )
            setattr(
                self, "fasilitas_layanan_id", new_fasilitas_layanan.fasilitas_layanan_id
            )



import attr
from datetime import datetime
from typing import Optional

from dapodik.base import BaseProp


@attr.dataclass(frozen=True, slots=True)
class JenisPtk:
    jenis_ptk_id: int
    jenis_ptk: str
    guru_kelas: str
    guru_matpel: str
    guru_bk: str
    guru_inklusi: str
    guru_pengganti: str
    pengawas_satdik: str
    pengawas_plb: str
    pengawas_matpel: str
    pengawas_bidang: str
    tas: str
    tendik_lainnya: str
    formal: str
    create_date: datetime
    last_update: datetime
    expired_date: Optional[datetime]
    last_sync: datetime

    def __str__(self):
        return self.jenis_ptk

    class Prop(BaseProp):
        @property
        def jenis_ptk(self) -> "JenisPtk":
            return self.dapodik._find(
                self.dapodik.jenis_ptk(),
                lambda x: x.jenis_ptk_id == getattr(self, "jenis_ptk_id"),
            )

        @jenis_ptk.setter
        def jenis_ptk(self, value: "JenisPtk"):
            new = self.dapodik._find(
                self.dapodik.jenis_ptk(),
                lambda x: x.jenis_ptk_id == value.jenis_ptk_id,
            )
            setattr(self, "jenis_ptk_id", new.jenis_ptk_id)



import json
import logging
import cattr
from datetime import date, datetime
from requests import Response, Session
from typing import Any, Callable, Optional, List, Type, TypeVar, Union
from uuid import UUID

from dapodik.utils.parser import str_to_date, str_to_datetime

T = TypeVar("T")


class BaseDapodik(object):
    def __init__(self, base_url: str = "http://localhost:5774/"):
        self._logger = logging.getLogger("Dapodik")
        self._session = Session()
        self._base_url = base_url
        self._register_hooks()

    @property
    def logger(self) -> logging.Logger:
        return self._logger

    @property
    def session(self) -> Session:
        return self._session

    @property
    def base_url(self) -> str:
        return self._base_url

    def _url(self, path: str) -> str:
        if path.startswith(self.base_url):
            return path
        return self.base_url + path.lstrip("/")

    def _rest_url(self, name: str) -> str:
        return self._url("rest/" + name.lstrip("/"))

    def _post(
        self,
        url: str,
        data: dict = None,
        json: dict = None,
        params: dict = None,
        headers: dict = None,
        **kwargs: Any,
    ) -> Response:
        return self.session.post(
            self._url(url),
            data=data,
            json=json,
            params=params,
            headers=headers,
            **kwargs,
        )

    def _get(
        self,
        url: str,
        params: dict = None,
        **kwargs: Any,
    ) -> Response:
        return self.session.get(
            self._url(url),
            params=params,
            **kwargs,
        )

    def _get_rows(
        self,
        path: str,
        cl: Type[T],
        query: Optional[dict] = None,
        key: Callable[[Any], Any] = lambda x: x["rows"],
        **kwargs: Any,
    ) -> T:
        res = self._get(
            url=path,
            params=query,
            **kwargs,
        )
        data: dict = json.loads(res.text)
        obj: Any = key(data) if callable(key) else data
        result = cattr.structure(obj, cl)
        if isinstance(result, list):
            for res in result:
                if not hasattr(res, "_dapodik"):
                    break
                setattr(res, "_dapodik", self)
        return result

    def _get_rest(
        self,
        path: str,
        cl: Type[T],
        page: int = 1,
        start: int = 9,
        limit: Union[int, str] = 50,
        query: Optional[dict] = None,
        prefix: str = "rest/",
        key: Callable[[Any], Any] = lambda x: x["rows"],
    ) -> T:
        params = {
            "page": page,
            "start": start,
            "limit": limit,
        }
        if query:
            params.update(query)
        return self._get_rows(prefix + path.lstrip("/"), cl=cl, query=params, key=key)

    def _query(self, *args, **kwargs) -> dict:
        query = dict()
        for key, val in dict(kwargs).items():
            if val is not None:
                query[key] = val
        return query

    def _register_hooks(self):
        cattr.register_structure_hook(date, lambda d, t: str_to_date(d))
        cattr.register_structure_hook(datetime, lambda d, t: str_to_datetime(d))
        cattr.register_structure_hook(UUID, lambda d, t: UUID(d))

    def _find(self, obj: List[T], is_this: Callable[[T], bool]) -> T:
        for o in obj:
            if is_this(o):
                return o
        raise ValueError("No obj found")



import attr
from datetime import datetime
from typing import Optional

from dapodik.base import BaseProp


@attr.dataclass(frozen=True, slots=True)
class BentukLembaga:
    bentuk_lembaga_id: int
    nama: str
    create_date: datetime
    last_update: datetime
    expired_date: Optional[datetime]
    last_sync: datetime

    def __str__(self):
        return self.nama

    class Prop(BaseProp):
        @property
        def bentuk_lembaga(self) -> "BentukLembaga":
            return self.dapodik._find(
                self.dapodik.bentuk_lembaga(),
                lambda x: x.bentuk_lembaga_id == getattr(self, "bentuk_lembaga_id"),
            )

        @bentuk_lembaga.setter
        def bentuk_lembaga(self, value: "BentukLembaga"):
            new_bentuk_lembaga_ = self.dapodik._find(
                self.dapodik.bentuk_lembaga(),
                lambda x: x.bentuk_lembaga_id == value.bentuk_lembaga_id,
            )
            setattr(self, "bentuk_lembaga_id", new_bentuk_lembaga_.bentuk_lembaga_id)



#!/usr/bin/env python

from .version import __version__, __dapodik_version__  # NOQA
from .version import __semester__, __tahun_ajaran__  # NOQA

from .auth import BaseAuth
from .rest import BaseRest
from .validasi import BaseValidasi
from .peserta_didik import BasePesertaDidik
from .gtk import BaseGtk
from .sarpras import BaseSarpras
from .rombongan_belajar import BaseRombonganBelajar
from .sekolah import BaseSekolah

from .dapodik import Dapodik

__all__ = [
    "BaseAuth",
    "BaseRest",
    "BaseValidasi",
    "BasePesertaDidik",
    "BaseGtk",
    "BaseSarpras",
    "BaseRombonganBelajar",
    "BaseSekolah",
    "Dapodik",
]



from datetime import datetime
from typing import Optional

import attr


@attr.dataclass
class SekolahLongitudinal:
    sekolah_id: str
    semester_id: str
    waktu_penyelenggaraan_id: str
    kontinuitas_listrik: str
    jarak_listrik: int
    wilayah_terpencil: str
    wilayah_perbatasan: str
    wilayah_transmigrasi: str
    wilayah_adat_terpencil: str
    wilayah_bencana_alam: str
    wilayah_bencana_sosial: str
    partisipasi_bos: str
    sertifikasi_iso_id: int
    sumber_listrik_id: str
    daya_listrik: str
    akses_internet_id: int
    akses_internet_2_id: int
    blob_id: Optional[str]
    create_date: datetime
    last_update: datetime
    soft_delete: str
    last_sync: datetime
    updater_id: str
    waktu_penyelenggaraan_id_str: str
    sekolah_id_str: str
    sekolah_longitudinal_id: str



from datetime import datetime, date
from typing import Optional
from uuid import UUID

import attr


@attr.dataclass
class Alat:
    id_alat: UUID
    jenis_sarana_id: int
    sekolah_id: UUID
    ptk_id: Optional[UUID]
    id_ruang: UUID
    id_hapus_buku: Optional[int]
    kepemilikan_sarpras_id: int
    kd_kl: Optional[str]
    kd_satker: Optional[str]
    kd_brg: Optional[str]
    nup: Optional[str]
    kode_eselon1: Optional[str]
    nama_eselon1: Optional[str]
    kode_sub_satker: Optional[str]
    nama_sub_satker: Optional[str]
    nama: str
    spesifikasi: Optional[str]
    tgl_hapus_buku: Optional[date]
    asal_data: int
    create_date: datetime
    last_update: datetime
    soft_delete: int
    last_sync: datetime
    updater_id: UUID
    id_ruang_str: str
    jenis_sarana_id_str: str
    sekolah_id_str: str
    key_match: str
    header: str
    vld_count: int = 0
    id_hapus_buku_str: Optional[str] = None
    jumlah: Optional[int] = None
    status_kelaikan: Optional[str] = None

    def __str__(self):
        return self.nama



from datetime import datetime, date
from typing import Optional

import attr


@attr.dataclass
class Sekolah:
    sekolah_id: str
    nama: str
    nama_nomenklatur: Optional[str]
    nss: str
    npsn: str
    bentuk_pendidikan_id: int
    alamat_jalan: str
    rt: Optional[str]
    rw: Optional[str]
    nama_dusun: Optional[str]
    desa_kelurahan: str
    kode_wilayah: str
    kode_pos: Optional[str]
    lintang: Optional[str]
    bujur: Optional[str]
    nomor_telepon: Optional[str]
    nomor_fax: Optional[str]
    email: Optional[str]
    website: Optional[str]
    kebutuhan_khusus_id: int
    status_sekolah: str
    sk_pendirian_sekolah: str
    tanggal_sk_pendirian: date
    status_kepemilikan_id: str
    yayasan_id: str
    sk_izin_operasional: str
    tanggal_sk_izin_operasional: date
    no_rekening: Optional[str]
    nama_bank: Optional[str]
    cabang_kcp_unit: Optional[str]
    rekening_atas_nama: Optional[str]
    mbs: int
    luas_tanah_milik: str
    luas_tanah_bukan_milik: str
    kode_registrasi: str
    npwp: Optional[str]
    nm_wp: Optional[str]
    keaktifan: int
    flag: Optional[str] = None
    create_date: Optional[datetime] = None
    last_update: Optional[datetime] = None
    soft_delete: Optional[str] = None
    last_sync: Optional[datetime] = None
    updater_id: Optional[str] = None
    bentuk_pendidikan_id_str: str = ""
    kode_wilayah_str: str = ""
    kebutuhan_khusus_id_str: str = ""
    yayasan_id_str: str = ""
    vld_count: int = 0



from datetime import datetime
from typing import Optional

import attr


@attr.dataclass
class Ruang:
    id_ruang: str
    jenis_prasarana_id: int
    sekolah_id: str
    id_bangunan: str
    kd_ruang: str
    nm_ruang: str
    lantai: str
    panjang: Optional[float]
    lebar: Optional[float]
    reg_pras: Optional[str]
    kapasitas: Optional[str]
    luas_ruang: Optional[float]
    luas_plester_m2: Optional[str]
    luas_plafon_m2: Optional[str]
    luas_dinding_m2: Optional[str]
    luas_daun_jendela_m2: Optional[str]
    luas_daun_pintu_m2: Optional[str]
    panj_kusen_m: Optional[str]
    luas_tutup_lantai_m2: Optional[str]
    panj_inst_listrik_m: Optional[str]
    jml_inst_listrik: Optional[str]
    panj_inst_air_m: Optional[str]
    jml_inst_air: Optional[str]
    panj_drainase_m: Optional[str]
    luas_finish_struktur_m2: Optional[str]
    luas_finish_plafon_m2: Optional[str]
    luas_finish_dinding_m2: Optional[str]
    luas_finish_kpj_m2: Optional[str]
    jenis_prasarana_id_str: str
    id_bangunan_str: str
    sekolah_id_str: str
    create_date: Optional[datetime] = None
    last_update: Optional[datetime] = None
    soft_delete: Optional[str] = None
    last_sync: Optional[datetime] = None
    updater_id: Optional[str] = None



from datetime import datetime
from typing import Optional

import attr


@attr.dataclass(frozen=True, slots=True)
class MstWilayah:
    kode_wilayah: str
    nama: str
    id_level_wilayah: int
    mst_kode_wilayah: Optional[str]
    negara_id: str
    asal_wilayah: Optional[str]
    kode_bps: Optional[str]
    kode_dagri: Optional[str]
    kode_keu: Optional[str]
    id_prov: Optional[str]
    id_kabkota: Optional[str]
    id_kec: Optional[str]
    a_desa: str
    a_kelurahan: str
    a_35: str
    a_urban: str
    kategori_desa_id: Optional[str]
    create_date: datetime
    last_update: datetime
    expired_date: Optional[datetime]
    last_sync: datetime

    def __str__(self):
        return self.nama



from typing import Optional

import attr


@attr.dataclass
class RegistrasiPesertaDidik:
    peserta_didik_id: str
    sekolah_id: str
    tanggal_masuk_sekolah: str
    nipd: str = ""
    registrasi_id: Optional[str] = "Admin.model.RegistrasiPesertaDidik-1"
    jurusan_sp_id: str = ""
    jenis_pendaftaran_id: int = 1
    jenis_keluar_id: str = ""
    tanggal_keluar: Optional[str] = None
    keterangan: str = ""
    no_skhun: str = ""
    id_hobby: int = -1
    id_cita: int = -1
    no_seri_ijazah: str = ""
    no_peserta_ujian: str = ""
    sekolah_asal: str = ""
    jurusan_sp_id_str: str = ""
    peserta_didik_id_str: str = ""
    sekolah_id_str: str = ""
    jenis_pendaftaran_id_str: str = ""
    id_hobby_str: str = ""
    id_cita_str: str = ""
    jenis_keluar_id_str: str = ""
    a_pernah_paud: int = 0
    a_pernah_tk: int = 0



import attr
from datetime import datetime
from typing import Optional

from dapodik.base import BaseProp


@attr.dataclass(frozen=True, slots=True)
class JenisPrasarana:
    jenis_prasarana_id: int
    nama: str
    a_unit_organisasi: str
    a_tanah: str
    a_bangunan: str
    a_ruang: str
    create_date: datetime
    last_update: datetime
    expired_date: Optional[datetime]
    last_sync: datetime

    def __str__(self):
        return self.nama

    class Prop(BaseProp):
        @property
        def jenis_prasarana(self) -> "JenisPrasarana":
            return self.dapodik._find(
                self.dapodik.jenis_prasarana(),
                lambda x: x.jenis_prasarana_id == getattr(self, "jenis_prasarana_id"),
            )

        @jenis_prasarana.setter
        def jenis_prasarana(self, value: "JenisPrasarana"):
            new = self.dapodik._find(
                self.dapodik.jenis_prasarana(),
                lambda x: x.jenis_prasarana_id == value.jenis_prasarana_id,
            )
            setattr(self, "jenis_prasarana_id", new.jenis_prasarana_id)



from .alat_dari_blockgrant import AlatDariBlockgrant
from .alat_longitudinal import AlatLongitudinal
from .alat import Alat
from .angkutan_dari_blockgrant import AngkutanDariBlockgrant
from .angkutan import Angkutan
from .bangunan_dari_blockgrant import BangunanDariBlockgrant
from .bangunan_longitudinal import BangunanLongitudinal
from .bangunan import Bangunan
from .buku_longitudinal import BukuLongitudinal
from .buku import Buku
from .ruang_longitudinal import RuangLongitudinal
from .ruang import Ruang
from .tanah_dari_blockgrant import TanahDariBlockgrant
from .tanah_longitudinal import TanahLongitudinal
from .tanah import Tanah

from .base import BaseSarpras


__all__ = [
    "AlatDariBlockgrant",
    "AlatLongitudinal",
    "Alat",
    "AngkutanDariBlockgrant",
    "Angkutan",
    "BangunanDariBlockgrant",
    "BangunanLongitudinal",
    "Bangunan",
    "BukuLongitudinal",
    "Buku",
    "RuangLongitudinal",
    "Ruang",
    "TanahDariBlockgrant",
    "TanahLongitudinal",
    "Tanah",
    "BaseSarpras",
]



import attr
from datetime import datetime
from typing import Optional

from dapodik.base import BaseProp


@attr.dataclass(frozen=True, slots=True)
class JenjangPendidikan:
    jenjang_pendidikan_id: int
    nama: str
    jenjang_lembaga: int
    jenjang_orang: int
    create_date: datetime
    last_update: datetime
    expired_date: Optional[datetime]
    last_sync: datetime

    def __str__(self):
        return self.nama

    class Prop(BaseProp):
        @property
        def jenjang_pendidikan(self) -> "JenjangPendidikan":
            return self.dapodik._find(
                self.dapodik.jenjang_pendidikan(),
                lambda x: x.jenjang_pendidikan_id
                == getattr(self, "jenjang_pendidikan_id"),
            )

        @jenjang_pendidikan.setter
        def jenjang_pendidikan(self, value: "JenjangPendidikan"):
            new = self.dapodik._find(
                self.dapodik.jenjang_pendidikan(),
                lambda x: x.jenjang_pendidikan_id == value.jenjang_pendidikan_id,
            )
            setattr(self, "jenjang_pendidikan_id", new.jenjang_pendidikan_id)



from typing import List

from dapodik.base import BaseDapodik

from . import AlatDariBlockgrant
from . import AlatLongitudinal
from . import Alat
from . import AngkutanDariBlockgrant
from . import Angkutan
from . import BangunanDariBlockgrant
from . import BangunanLongitudinal
from . import Bangunan
from . import BukuLongitudinal
from . import Buku
from . import RuangLongitudinal
from . import Ruang
from . import TanahDariBlockgrant
from . import TanahLongitudinal
from . import Tanah


class BaseSarpras(BaseDapodik):
    def alat_dari_blockgrant(
        self, page: int = 1, start: int = 0, limit: int = 50
    ) -> List[AlatDariBlockgrant]:
        return self._get_rest(
            "AlatDariBlockgrant", List[AlatDariBlockgrant], page, start, limit
        )

    def alat_longitudinal(
        self, page: int = 1, start: int = 0, limit: int = 50
    ) -> List[AlatLongitudinal]:
        return self._get_rest(
            "AlatLongitudinal", List[AlatLongitudinal], page, start, limit
        )

    def alat(self, page: int = 1, start: int = 0, limit: int = 50) -> List[Alat]:
        return self._get_rest("Alat", List[Alat], page, start, limit)

    def angkutan_dari_blockgrant(
        self, page: int = 1, start: int = 0, limit: int = 50
    ) -> List[AngkutanDariBlockgrant]:
        return self._get_rest(
            "AngkutanDariBlockgrant", List[AngkutanDariBlockgrant], page, start, limit
        )

    def angkutan(
        self, page: int = 1, start: int = 0, limit: int = 50
    ) -> List[Angkutan]:
        return self._get_rest("Angkutan", List[Angkutan], page, start, limit)

    def bangunan_dari_blockgrant(
        self, page: int = 1, start: int = 0, limit: int = 50
    ) -> List[BangunanDariBlockgrant]:
        return self._get_rest(
            "BangunanDariBlockgrant", List[BangunanDariBlockgrant], page, start, limit
        )

    def bangunan_longitudinal(
        self, page: int = 1, start: int = 0, limit: int = 50
    ) -> List[BangunanLongitudinal]:
        return self._get_rest(
            "BangunanLongitudinal", List[BangunanLongitudinal], page, start, limit
        )

    def bangunan(
        self, page: int = 1, start: int = 0, limit: int = 50
    ) -> List[Bangunan]:
        return self._get_rest("Bangunan", List[Bangunan], page, start, limit)

    def buku_longitudinal(
        self, page: int = 1, start: int = 0, limit: int = 50
    ) -> List[BukuLongitudinal]:
        return self._get_rest(
            "BukuLongitudinal", List[BukuLongitudinal], page, start, limit
        )

    def buku(self, page: int = 1, start: int = 0, limit: int = 50) -> List[Buku]:
        return self._get_rest("Buku", List[Buku], page, start, limit)

    def ruang_longitudinal(
        self, page: int = 1, start: int = 0, limit: int = 50
    ) -> List[RuangLongitudinal]:
        return self._get_rest(
            "RuangLongitudinal", List[RuangLongitudinal], page, start, limit
        )

    def ruang(self, page: int = 1, start: int = 0, limit: int = 50) -> List[Ruang]:
        return self._get_rest("Ruang", List[Ruang], page, start, limit)

    def tanah_dari_blockgrant(
        self, page: int = 1, start: int = 0, limit: int = 50
    ) -> List[TanahDariBlockgrant]:
        return self._get_rest(
            "TanahDariBlockgrant", List[TanahDariBlockgrant], page, start, limit
        )

    def tanah_longitudinal(
        self, page: int = 1, start: int = 0, limit: int = 50
    ) -> List[TanahLongitudinal]:
        return self._get_rest(
            "TanahLongitudinal", List[TanahLongitudinal], page, start, limit
        )

    def tanah(self, page: int = 1, start: int = 0, limit: int = 50) -> List[Tanah]:
        return self._get_rest("Tanah", List[Tanah], page, start, limit)



from datetime import datetime

import attr


@attr.dataclass(frozen=True, slots=True)
class SyncLog:
    id_instalasi: str
    begin_sync: datetime
    end_sync: datetime
    sync_media: str
    is_success: str
    selisih_waktu_server: str
    alamat_ip: str
    pengguna_id: str
    sync_log_id: str



import attr
from datetime import datetime
from typing import Optional

from dapodik.base import BaseProp


@attr.dataclass(frozen=True, slots=True)
class Gmd:
    id_gmd: str
    nm_gmd: str
    create_date: datetime
    last_update: datetime
    expired_date: Optional[datetime]
    last_sync: datetime

    def __str__(self):
        return self.nm_gmd

    class Prop(BaseProp):
        @property
        def gmd(self) -> "Gmd":
            return self.dapodik._find(
                self.dapodik.gmd(),
                lambda x: x.id_gmd == getattr(self, "id_gmd"),
            )

        @gmd.setter
        def gmd(self, value: "Gmd"):
            new_id_gmd = self.dapodik._find(
                self.dapodik.gmd(),
                lambda x: x.id_gmd == value.id_gmd,
            )
            setattr(self, "id_gmd", new_id_gmd.id_gmd)



from datetime import datetime, date
from typing import Optional

import attr


@attr.dataclass(frozen=True, slots=True)
class Kurikulum:
    kurikulum_id: int
    nama_kurikulum: str
    mulai_berlaku: date
    sistem_sks: str
    total_sks: str
    jenjang_pendidikan_id: str
    jurusan_id: Optional[str]
    create_date: datetime
    last_update: datetime
    expired_date: Optional[datetime]
    last_sync: datetime
    sek: str

    def __str__(self):
        return self.nama_kurikulum



from datetime import datetime
from typing import Optional
from uuid import UUID

import attr


@attr.dataclass(frozen=True, slots=True)
class RombelPortal:
    rombongan_belajar_id: UUID
    semester_id: int
    id_ruang: UUID
    sekolah_id: UUID
    tingkat_pendidikan_id: int
    jurusan_sp_id: Optional[str]
    kurikulum_id: int
    nama: str
    ptk_id: UUID
    moving_class: int
    jenis_rombel: int
    sks: int
    tanggal_mulai: datetime
    tanggal_selesai: datetime
    kebutuhan_khusus_id: int
    create_date: datetime
    last_update: datetime
    soft_delete: int
    last_sync: datetime
    updater_id: UUID
    no: int
    laki_laki: int
    perempuan: int
    keluar: int
    mutasi: int
    do: int
    jumlah: int



from functools import partialmethod
from typing import List

from dapodik.base import BaseDapodik, DapodikMessage
from . import (
    PesertaDidikBaru,
    PesertaDidikLongitudinal,
    PesertaDidik,
    RegistrasiPesertaDidik,
)


class BasePesertaDidik(BaseDapodik):
    def peserta_didik_baru(self) -> List[PesertaDidikBaru]:
        return self._get_rest("PesertaDidikBaru", List[PesertaDidikBaru])

    def peserta_didik_longitudinal(
        self,
        peserta_didik_id: str,
        page: int = 1,
        start: int = 0,
        limit: int = 50,
    ) -> List[PesertaDidikLongitudinal]:
        query = {
            "peserta_didik_id": peserta_didik_id,
            "page": page,
            "start": start,
            "limit": limit,
        }
        return self._get_rest(
            "PesertaDidikLongitudinal", List[PesertaDidikLongitudinal], query=query
        )

    def peserta_didik(
        self,
        sekolah_id: str,
        page: int = 1,
        start: int = 0,
        limit: int = 25,
        nama: str = None,
        pd_module: str = "pdterdaftar",
    ) -> List[PesertaDidik]:
        """Dapatkan data peserta didik
        Args:
            sekolah_id (str): ID sekolah
            pd_module (str, optional): Modul. Defaults to "pdterdaftar". pdkeluar | pdterdaftar
            nama (str, optional): Filter berdasarkan nama. Defaults to None.
            page (int, optional): Halaman data. Defaults to 1.
            start (int, optional): Mulai dari. Defaults to 0.
            limit (int, optional): Batas data. Defaults to 25.
        Returns:
            List[PesertaDidik]: list dari peserta didik
        """
        params = {
            "sekolah_id": sekolah_id,
            "pd_module": pd_module,
            "page": page,
            "start": start,
            "limit": limit,
        }
        if isinstance(nama, str):
            params["nama"] = nama
        return self._get_rest("PesertaDidik", List[PesertaDidik], query=params)

    peserta_didik_keluar = partialmethod(peserta_didik, pd_module="pdkeluar")

    def registrasi_peserta_didik(self) -> List[RegistrasiPesertaDidik]:
        return self._get_rest("RegistrasiPesertaDidik", List[RegistrasiPesertaDidik])

    def salin_periodik_longitudinal(
        self,
        sekolah_id: str,
        semester_yl: str,
        semester_now: str,
        table: str = "peserta_didik_longitudinal",
    ) -> DapodikMessage:
        """Menyalin semua Data Periodik Peserta Didik aktif dari semester_yl ke semester_now
        Args:
            sekolah_id (str): ID sekolah
            semester_yl (str): ID semester sumber
            semester_now (str): ID semester sekarang
            table (str, optional): Table dari data. Defaults to "peserta_didik_longitudinal".
        Returns:
            DapodikMessage: Pesan
        """
        data = {
            "table": table,
            "sekolah_id": sekolah_id,
            "semester_yl": semester_yl,
            "semester_now": semester_now,
        }
        res = self._post("salinPeriodik", data)
        return DapodikMessage.from_str(res.text)

    def save_pdb(self, pdb: PesertaDidikBaru) -> DapodikMessage:
        """Save Pdb to Pd
        Args:
            pdb (PesertaDidikBaru): Instance dari PesertaDidikBaru
        Returns:
            DapodikMessage: Pesan
        """
        data = {"pdb_id": pdb.pdb_id}
        res = self._post("customrest/savePdb", data)
        return DapodikMessage.from_str(res.text)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['dapodik',
 'dapodik.auth',
 'dapodik.base',
 'dapodik.gtk',
 'dapodik.peserta_didik',
 'dapodik.rest',
 'dapodik.rombongan_belajar',
 'dapodik.sarpras',
 'dapodik.sekolah',
 'dapodik.utils',
 'dapodik.validasi']

package_data = \
{'': ['*']}

install_requires = \
['attrs>=20.3.0,<21.0.0',
 'beautifulsoup4>=4.9.3,<5.0.0',
 'cattrs>=1.4.0,<2.0.0',
 'requests>=2.25.1,<3.0.0']

entry_points = \
{'console_scripts': ['dapodik = dapodik.__main__:main']}

setup_kwargs = {
    'name': 'dapodik',
    'version': '0.14.0',
    'description': 'SDK python untuk aplikasi dapodik.',
    'long_description': "# dapodik\n\n[![dapodik - PyPi](https://img.shields.io/pypi/v/dapodik)](https://pypi.org/project/dapodik/)\n[![Supported Python versions](https://img.shields.io/pypi/pyversions/dapodik)](https://pypi.org/project/dapodik/)\n[![LISENSI](https://img.shields.io/github/license/dapodix/dapodik)](https://github.com/dapodix/dapodik/blob/master/LISENSI)\n[![Tutorial](https://img.shields.io/badge/Tutorial-Penggunaan-informational)](https://github.com/dapodix/dapodik/wiki)\n[![Tests](https://github.com/dapodix/dapodik/workflows/Tests/badge.svg)](https://github.com/dapodix/dapodik/actions?query=workflow%3ATests)\n[![codecov](https://codecov.io/gh/dapodix/dapodik/branch/master/graph/badge.svg)](https://codecov.io/gh/dapodix/dapodik)\n[![Code Style - Black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)\n\nSDK python untuk aplikasi dapodik.\n\n## Install\n\nPastikan [python 3.7+](https://www.python.org/ftp/python/3.7.9/python-3.7.9-amd64.exe) terinstall,\nkemudian jalankan perintah di bawah dalam Command Prompt atau Powershell (di Windows + X):\n\n```bash\npip install --upgrade dapodik\n```\n\n## Penggunaan\n\nContoh pennggunaan\n\n```python\nfrom dapodik import Dapodik\n\nemail = 'email@saya.com'\npassword = 'password dapodik'\n\nd = Dapodik(email, password)\nsekolah = d.sekolah()\ndaftar_peserta_didik = d.peserta_didik(sekolah_id=sekolah.sekolah_id)\nfor peserta_didik in daftar_peserta_didik:\n    print(peserta_didik.nama)\n```\n\n## Legal / Hukum\n\nKode ini sama sekali tidak berafiliasi dengan, diizinkan, dipelihara, disponsori atau didukung oleh [Kemdikbud](https://kemdikbud.go.id/) atau afiliasi atau anak organisasinya. Ini adalah perangkat lunak yang independen dan tidak resmi. _Gunakan dengan risiko Anda sendiri._\n",
    'author': 'hexatester',
    'author_email': 'habibrohman@protonmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://dapodix.github.io/dapodik',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)



from dapodik import __semester__

from . import BaseAuth
from . import BaseRest
from . import BaseValidasi
from . import BasePesertaDidik
from . import BaseGtk
from . import BaseSarpras
from . import BaseRombonganBelajar
from . import BaseSekolah
from .constants import HEADERS


class Dapodik(
    BaseAuth,
    BaseRest,
    BaseValidasi,
    BasePesertaDidik,
    BaseGtk,
    BaseSarpras,
    BaseRombonganBelajar,
    BaseSekolah,
):
    def __init__(
        self,
        username: str,
        password: str,
        semester_id: str = __semester__,
        server: str = "http://localhost:5774/",
        pengguna: int = 0,
        rememberme: bool = True,
    ):
        super(Dapodik, self).__init__(server)
        self.session.headers.update(HEADERS)
        self.daftar_pengguna = self.login(
            username, password, rememberme, semester_id, pengguna
        )
        if self.daftar_pengguna:
            self.logger.info(f"Berhasil login {username}")

    def __del__(self):
        self.logout()



from datetime import datetime
from typing import Optional

import attr


@attr.dataclass(frozen=True, slots=True)
class StatusKeaktifanPegawai:
    status_keaktifan_id: int
    nama: str
    create_date: datetime
    last_update: datetime
    expired_date: Optional[datetime]
    last_sync: datetime

    def __str__(self):
        return self.nama



import attr
from datetime import datetime
from typing import Optional

from dapodik.base import BaseProp


@attr.dataclass(frozen=True, slots=True)
class JenisGugus:
    jenis_gugus_id: int
    jenis_gugus: str
    create_date: datetime
    last_update: datetime
    expired_date: Optional[datetime]
    last_sync: datetime

    def __str__(self):
        return self.jenis_gugus

    class Prop(BaseProp):
        @property
        def jenis_gugus(self) -> "JenisGugus":
            return self.dapodik._find(
                self.dapodik.jenis_gugus(),
                lambda x: x.jenis_gugus_id == getattr(self, "jenis_gugus_id"),
            )

        @jenis_gugus.setter
        def jenis_gugus(self, value: "JenisGugus"):
            new_jenis_gugus = self.dapodik._find(
                self.dapodik.jenis_gugus(),
                lambda x: x.jenis_gugus_id == value.jenis_gugus_id,
            )
            setattr(self, "jenis_gugus_id", new_jenis_gugus.jenis_gugus_id)



from typing import List, Union

from dapodik.base import BaseDapodik, DapodikMessage
from dapodik.rest import TingkatPendidikan
from dapodik.version import __semester__

from . import AnggotaRombel
# from . import Pembelajaran
from . import RombelPortal
from . import RombonganBelajar


class BaseRombonganBelajar(BaseDapodik):
    def anggota_rombel(
        self,
        rombongan_belajar_id: str,
        page: int = 1,
        start: int = 0,
        limit: Union[int, str] = 25,
    ) -> List[AnggotaRombel]:
        """Mengammbil data-data anggota rombel
        Args:
            rombongan_belajar_id (Union[UUID, str]): ID rombongan belajar
            page (int, optional): Halaman data ke. Defaults to 1.
            start (int, optional): Mulai dari. Defaults to 0.
            limit (int, str, optional): Batas data yang dikembalikan. Defaults to 25. int atau unlimited
        Returns:
            List[AnggotaRombel]: list dari AnggotaRombel
        """
        return self._get_rest(
            path="allanggotarombel/" + str(rombongan_belajar_id),
            cl=List[AnggotaRombel],
            page=page,
            start=start,
            limit=limit,
            prefix="customrest/",
            key=lambda x: x,
        )

    def rombel_portal(
        self,
        sekolah_id: str,
        page: int = 1,
        start: int = 0,
        limit: int = 25,
    ) -> List[RombelPortal]:
        """rombel_portal dashboard
        Args:
            sekolah_id (UID): ID sekolah
            page (int, optional): Halaman ke. Defaults to 1.
            start (int, optional): Mulai dari. Defaults to 0.
            limit (int, optional): Batas data yang dikembalikan. Defaults to 25.
        Returns:
            List[RombelPortal]: list dari RombelPortal
        """
        return self._get_rest(
            path="RombelPortal",
            cl=List[RombelPortal],
            page=page,
            start=start,
            limit=limit,
            query={"sekolah_id": sekolah_id},
            prefix="customrest/",
        )

    def rombongan_belajar(
        self,
        sekolah_id: str,
        semester_id: str = __semester__,
        ascending: str = "#INjenis_rombel,tingkat_pendidikan_id,nama",
        callback: str = "rombonganbelajar",
        jenis_rombel: str = "#IN1,5,6,7,8,9,10",
        sks=0,
        limit: Union[int, str] = "unlimited",
        page: int = 1,
        start: int = 0,
    ) -> List[RombonganBelajar]:
        """Mengammbil data-data rombongan belajar
        Args:
            sekolah_id (str): ID sekolah
            semester_id (str, optional): ID semester. Defaults to __semester__.
            ascending (str, optional): Sortir. Defaults to "#INjenis_rombel,tingkat_pendidikan_id,nama".
            callback (str, optional): Callback. Defaults to "rombonganbelajar".
            jenis_rombel (str, optional): Filter jenis rombel. Defaults to "#IN1,5,6,7,8,9,10".
            sks (int, optional): Jumlah sks. Defaults to 0.
            limit (Union[int, Literal[, optional): Batas data yang dikembalikan. Defaults to "unlimited".
            page (int, optional): Halaman data-data yang diambil. Defaults to 1.
            start (int, optional): Mulai. Defaults to 0.
        Returns:
            List[RombonganBelajar]: list dari RombonganBelajar
        """
        params = {
            "sekolah_id": sekolah_id,
            "semester_id": semester_id,
            "ascending": ascending,
            "callback": callback,
            "jenis_rombel": jenis_rombel,
            "sks": sks,
            "page": page,
            "start": start,
            "limit": limit,
        }
        return self._get_rest(
            path="RombonganBelajar",
            cl=List[RombonganBelajar],
            query=params,
        )

    def kenaikan_kelas(
        self, rombongan_belajar_id: str, semester_id: str = __semester__
    ) -> DapodikMessage:
        """kenaikan_kelas rombongan belajar
        Args:
            rombongan_belajar_id (Union[UUID, str]): ID dari rombongan belajar
            semester_id (str, optional): Naikkan ke semester. Defaults dapodik.__semester__.
        Returns:
            DapodikMessage: Pesan sukses / tidak
        """
        data = dict(
            rombongan_belajar_id=rombongan_belajar_id,
            semester_id=semester_id,
        )
        res = self._post("kenaikankelas", data)
        return DapodikMessage.from_str(res.text)

    def filter_tingkat_pendidikan(
        self,
        fromui: str = None,
        callback: str = "rombonganbelajar",
        jurusan_id: int = None,
        page: int = 1,
        start: int = 0,
        limit: int = 50,
    ) -> List[TingkatPendidikan]:
        """filter_tingkat_pendidikan [summary]
        Args:
            fromui (str, optional): Misal tingkatpendidikanpaud. Defaults "".
            callback (str, optional): callback. Defaults "rombonganbelajar".
            jurusan_id (int, optional): id jurusan. Defaults "".
            page (int, optional): halaman. Defaults 1.
            start (int, optional): mulai. Defaults 0.
            limit (int, optional): batas. Defaults 50.
        Returns:
            List[TingkatPendidikan]: list dari TingkatPendidikan
        """
        params = {
            "callback": callback,
            "jurusan_id": jurusan_id or "",
            "fromui": fromui or "",
            "page": page,
            "start": start,
            "limit": limit,
        }
        return self._get_rest(
            path="filtertingkatpendidikan",
            cl=List[TingkatPendidikan],
            query=params,
        )



from functools import partialmethod
from typing import List, Optional

from dapodik.base import BaseDapodik
from dapodik.version import __tahun_ajaran__

from . import PtkTerdaftar
from . import Ptk


class BaseGtk(BaseDapodik):
    def ptk(
        self,
        sekolah_id: str,
        tahun_ajaran_id: str = __tahun_ajaran__,
        ptk_module: Optional[str] = None,
        jenis_gtk: Optional[str] = None,
        limit: int = 25,
        penugasan_null: Optional[int] = None,
        page: int = 1,
        start: int = 0,
    ) -> List[Ptk]:
        """ptk mengambil data ptk

        Args:
            sekolah_id (str): Sekolah ID
            tahun_ajaran_id (str, optional): Id tahun ajaran. Defaults to __tahun_ajaran__.
            ptk_module (Optional[str], optional): antara `ptkterdaftar` dan `ptkkeluar`. Defaults to None.
            jenis_gtk (Optional[str], optional): antara `guru` dan `tendik`. Defaults to None.
            limit (int, optional): batas data yang dikembalikan. Defaults to 25.
            penugasan_null (Optional[int], optional): Tambpilkan data dengan penugasan kosong. Defaults to None.
            page (int, optional): Halaman data. Defaults to 1.
            start (int, optional): Mulai dari. Defaults to 0.

        Returns:
            List[Ptk]: List dari data Ptk
        """
        query = self._query(
            entry_sekolah_id=sekolah_id,
            ptk_module=ptk_module,
            tahun_ajaran_id=tahun_ajaran_id,
            jenis_gtk=jenis_gtk,
            limit=limit,
            penugasan_null=penugasan_null,
            page=page,
            start=start,
        )
        return self._get_rest(
            path="ptk" if ptk_module == "ptkkeluar" else "Ptk",
            cl=List[Ptk],
            query=query,
            prefix="customrest/" if ptk_module == "ptkkeluar" else "rest/",
        )

    guru = partialmethod(
        ptk,
        ptk_module="ptkterdaftar",
        jenis_gtk="guru",
        penugasan_null=2,
    )

    tendik = partialmethod(
        ptk,
        ptk_module="ptkterdaftar",
        jenis_gtk="tendik",
        penugasan_null=2,
    )

    ptk_keluar = partialmethod(
        ptk,
        ptk_module="ptkkeluar",
    )

    def ptk_terdaftar(
        self,
        ptk_id: Optional[str] = None,
        sekolah_id: Optional[str] = None,
        tahun_ajaran_id: Optional[str] = None,
        page: int = 1,
        start: int = 0,
        limit: int = 50,
    ) -> List[PtkTerdaftar]:
        """ptk_terdaftar mengambil data PtkTerdaftar

        Args:
            ptk_id (Optional[str], optional): ID milik Ptk. Defaults to None.
            sekolah_id (Optional[str], optional): Sekolah ID. Defaults to None.
            tahun_ajaran_id (Optional[str], optional): Tahun ajar ID. Defaults to None.
            page (int, optional): Halaman. Defaults to 1.
            start (int, optional): Mulai dari. Defaults to 0.
            limit (int, optional): Batas data. Defaults to 50.

        Returns:
            List[PtkTerdaftar]: [description]
        """
        query = self._query(
            sekolah_id=sekolah_id,
            tahun_ajaran_id=tahun_ajaran_id,
            ptk_id=ptk_id,
            page=page,
            start=start,
            limit=limit,
        )
        return self._get_rest("PtkTerdaftar", List[PtkTerdaftar], query=query)



class AuthException(BaseException):
    pass


class PasswordSalah(AuthException):
    pass


class PenggunaTidakTerdaftar(AuthException):
    pass


class ServerTidakMerespon(BaseException):
    pass



import attr
from datetime import datetime
from typing import Optional

from dapodik.base import BaseProp


@attr.dataclass(frozen=True, slots=True)
class JenisSarana:
    jenis_sarana_id: int
    nama: str
    kelompok: Optional[str]
    perlu_penempatan: int
    keterangan: str
    a_alat: int
    a_angkutan: int
    spm_qty_min_per_siswa: str
    spm_qty_min_per_sekolah: int
    create_date: datetime
    last_update: datetime
    expired_date: Optional[datetime]
    last_sync: datetime

    class Prop(BaseProp):
        @property
        def jenis_sarana(self) -> "JenisSarana":
            return self.dapodik._find(
                self.dapodik.jenis_sarana(),
                lambda x: x.jenis_sarana_id == getattr(self, "jenis_sarana_id"),
            )

        @jenis_sarana.setter
        def jenis_sarana(self, value: "JenisSarana"):
            new = self.dapodik._find(
                self.dapodik.jenis_sarana(),
                lambda x: x.jenis_sarana_id == value.jenis_sarana_id,
            )
            setattr(self, "jenis_sarana_id", new.jenis_sarana_id)



from .agama import Agama
from .akreditasi import Akreditasi
from .akses_internet import AksesInternet
from .alat_transportasi import AlatTransportasi
from .bank import Bank
from .bentuk_lembaga import BentukLembaga
from .biblio import Biblio
from .child_delete import ChildDelete
from .fasilitas_layanan import FasilitasLayanan
from .gmd import Gmd
from .jadwal_paud import JadwalPaud
from .jenis_cita import JenisCita
from .jenis_gugus import JenisGugus
from .jenis_hapus_buku import JenisHapusBuku
from .jenis_hobby import JenisHobby
from .jenis_keluar import JenisKeluar
from .jenis_lk import JenisLk
from .jenis_pendaftaran import JenisPendaftaran
from .jenis_prasarana import JenisPrasarana
from .jenis_ptk import JenisPtk
from .jenis_rombel import JenisRombel
from .jenis_sarana import JenisSarana
from .jenis_tinggal import JenisTinggal
from .jenjang_pendidikan import JenjangPendidikan
from .jurusan import Jurusan
from .kategori_tk import KategoriTk
from .keahlian_laboratorium import KeahlianLaboratorium
from .kebutuhan_khusus import KebutuhanKhusus
from .klasifikasi_lembaga import KlasifikasiLembaga
from .kurikulum import Kurikulum
from .lembaga_pengangkat import LembagaPengangkat
from .mata_pelajaran import MataPelajaran
from .mst_wilayah import MstWilayah
from .pangkat_golongan import PangkatGolongan
from .pekerjaan import Pekerjaan
from .penghasilan import Penghasilan
from .role_pengguna import RolePengguna
from .status_keaktifan_pegawai import StatusKeaktifanPegawai
from .status_kepegawaian import StatusKepegawaian
from .status_kepemilikan_sarpras import StatusKepemilikanSarpras
from .sumber_air import SumberAir
from .sumber_dana_sekolah import SumberDanaSekolah
from .sumber_gaji import SumberGaji
from .sumber_listrik import SumberListrik
from .sync_log import SyncLog
from .tahun_ajaran import TahunAjaran
from .tingkat_pendidikan import TingkatPendidikan
from .waktu_penyelenggaraan import WaktuPenyelenggaraan

from .base import BaseRest


__all__ = [
    "Agama",
    "Akreditasi",
    "AksesInternet",
    "AlatTransportasi",
    "Bank",
    "BentukLembaga",
    "Biblio",
    "ChildDelete",
    "FasilitasLayanan",
    "Gmd",
    "JadwalPaud",
    "JenisCita",
    "JenisGugus",
    "JenisHapusBuku",
    "JenisHobby",
    "JenisKeluar",
    "JenisLk",
    "JenisPendaftaran",
    "JenisPrasarana",
    "JenisPtk",
    "JenisRombel",
    "JenisSarana",
    "JenisTinggal",
    "JenjangPendidikan",
    "Jurusan",
    "KategoriTk",
    "KeahlianLaboratorium",
    "KebutuhanKhusus",
    "KlasifikasiLembaga",
    "Kurikulum",
    "LembagaPengangkat",
    "MataPelajaran",
    "MstWilayah",
    "PangkatGolongan",
    "Pekerjaan",
    "Penghasilan",
    "RolePengguna",
    "StatusKeaktifanPegawai",
    "StatusKepegawaian",
    "StatusKepemilikanSarpras",
    "SumberAir",
    "SumberDanaSekolah",
    "SumberGaji",
    "SumberListrik",
    "SyncLog",
    "TahunAjaran",
    "TingkatPendidikan",
    "WaktuPenyelenggaraan",
    "BaseRest",
]
